@@ -20,7 +20,7 @@ package MongoDB::BSON;
 # ABSTRACT: Tools for serializing and deserializing data in BSON form
 
 use version;
-our $VERSION = 'v0.999.998.2'; # TRIAL
+our $VERSION = 'v0.999.998.3'; # TRIAL
 
 use XSLoader;
 XSLoader::load("MongoDB", $VERSION);
@@ -86,18 +86,6 @@ $MongoDB::BSON::char = '$';
 
 $MongoDB::BSON::utf8_flag_on = 1;
 
-#pod =head2 Return boolean values as booleans instead of integers
-#pod
-#pod     $MongoDB::BSON::use_boolean = 1
-#pod
-#pod By default, booleans are deserialized as integers.  If you would like them to be
-#pod deserialized as L<boolean/true> and L<boolean/false>, set
-#pod C<$MongoDB::BSON::use_boolean> to 1.
-#pod
-#pod =cut
-
-$MongoDB::BSON::use_boolean = 0;
-
 #pod =head2 Return binary data as instances of L<MongoDB::BSON::Binary> instead of
 #pod string refs.
 #pod
@@ -139,6 +127,20 @@ sub encode_bson {
     return $bson;
 }
 
+#pod =head1 UNSUPPORTED
+#pod
+#pod =head2 Return boolean values as integers
+#pod
+#pod Previously, the MongoDB driver documented the C<$MongoDB::BSON::use_boolean>
+#pod global for toggling whether boolean BSON values were deserialized as integers
+#pod or L<boolean> objects.  However, this value was actually never used and the
+#pod driver always deserialized objects as L<boolean> values.  Rather than fix this
+#pod and break people's code, instead this option is no longer supported.  A future
+#pod driver will provide a means for customizing the deserialization of boolean BSON
+#pod values without the use of a global variable.
+#pod
+#pod =cut
+
 __PACKAGE__->meta->make_immutable;
 
 1;
@@ -155,7 +157,7 @@ MongoDB::BSON - Tools for serializing and deserializing data in BSON form
 
 =head1 VERSION
 
-version v0.999.998.2
+version v0.999.998.3
 
 =head1 NAME
 
@@ -203,14 +205,6 @@ NOTE:
 
 If you turn off utf8 flag, the string  length will compute as bytes, and is_utf8 will return false.
 
-=head2 Return boolean values as booleans instead of integers
-
-    $MongoDB::BSON::use_boolean = 1
-
-By default, booleans are deserialized as integers.  If you would like them to be
-deserialized as L<boolean/true> and L<boolean/false>, set
-C<$MongoDB::BSON::use_boolean> to 1.
-
 =head2 Return binary data as instances of L<MongoDB::BSON::Binary> instead of
 string refs.
 
@@ -220,6 +214,22 @@ For backwards compatibility, binary data is deserialized as a string ref.  If
 you would like to have it deserialized as instances of L<MongoDB::BSON::Binary>
 (to, say, preserve the subtype), set C<$MongoDB::BSON::use_binary> to 1.
 
+=head1 UNSUPPORTED
+
+=head2 Return boolean values as integers
+
+Previously, the MongoDB driver documented the C<$MongoDB::BSON::use_boolean>
+global for toggling whether boolean BSON values were deserialized as integers
+or L<boolean> objects.  However, this value was actually never used and the
+driver always deserialized objects as L<boolean> values.  Rather than fix this
+and break people's code, instead this option is no longer supported.  A future
+driver will provide a means for customizing the deserialization of boolean BSON
+values without the use of a global variable.
+
+=for Pod::Coverage decode_bson
+encode_bson
+generate_oid
+
 =head1 AUTHORS
 
 =over 4
