@@ -20,9 +20,10 @@ package MongoDB::BSON::Binary;
 # ABSTRACT: Binary type
 
 use version;
-our $VERSION = 'v0.999.998.2'; # TRIAL
+our $VERSION = 'v0.999.998.3'; # TRIAL
 
 use Moose;
+use Types::Standard -types;
 use namespace::clean -except => 'meta';
 
 #pod =head1 NAME
@@ -96,7 +97,7 @@ use constant {
 
 has data => (
     is => 'ro',
-    isa => 'Str',
+    isa => Str,
     required => 1
 );
 
@@ -108,7 +109,7 @@ has data => (
 
 has subtype => (
     is => 'ro',
-    isa => 'Int',
+    isa => Int,
     required => 0,
     default => MongoDB::BSON::Binary->SUBTYPE_GENERIC
 );
@@ -155,7 +156,7 @@ MongoDB::BSON::Binary - Binary type
 
 =head1 VERSION
 
-version v0.999.998.2
+version v0.999.998.3
 
 =head1 SYNOPSIS
 
