@@ -2,20 +2,21 @@ package MongoDB::BSON::Regexp;
 # ABSTRACT: Regular expression type
 
 use version;
-our $VERSION = 'v0.999.998.2'; # TRIAL
+our $VERSION = 'v0.999.998.3'; # TRIAL
 
 use Moose;
+use Types::Standard -types;
 use namespace::clean -except => 'meta';
 
 has pattern => ( 
     is       => 'ro',
-    isa      => 'Str',
+    isa      => Str,
     required => 1,
 );
 
 has flags => ( 
     is        => 'ro',
-    isa       => 'Str',
+    isa       => Str,
     required  => 0,
     predicate => 'has_flags',
     writer    => '_set_flags',
@@ -60,7 +61,7 @@ MongoDB::BSON::Regexp - Regular expression type
 
 =head1 VERSION
 
-version v0.999.998.2
+version v0.999.998.3
 
 =head1 AUTHORS
 
