@@ -19,7 +19,7 @@ package MongoDB::BulkWrite;
 # ABSTRACT: MongoDB bulk write interface
 
 use version;
-our $VERSION = 'v0.999.998.2'; # TRIAL
+our $VERSION = 'v0.999.998.3'; # TRIAL
 
 use MongoDB::Error;
 use MongoDB::OID;
@@ -29,6 +29,7 @@ use MongoDB::BulkWriteView;
 use Syntax::Keyword::Junction qw/any/;
 
 use Moose;
+use Types::Standard -types;
 use namespace::clean -except => 'meta';
 
 #pod =attr collection (required)
@@ -39,7 +40,7 @@ use namespace::clean -except => 'meta';
 
 has 'collection' => (
     is       => 'ro',
-    isa      => 'MongoDB::Collection',
+    isa      => InstanceOf['MongoDB::Collection'],
     required => 1,
 );
 
@@ -52,20 +53,20 @@ has 'collection' => (
 
 has 'ordered' => (
     is       => 'ro',
-    isa      => 'Bool',
+    isa      => Bool,
     required => 1,
 );
 
 has '_executed' => (
     is       => 'rw',
-    isa      => 'Bool',
+    isa      => Bool,
     init_arg => undef,
     default  => 0,
 );
 
 has '_queue' => (
     is       => 'rw',
-    isa      => 'ArrayRef[ArrayRef]',
+    isa      => ArrayRef[ArrayRef],
     init_arg => undef,
     default  => sub { [] },
     traits   => ['Array'],
@@ -79,18 +80,18 @@ has '_queue' => (
 
 has '_database' => (
     is         => 'ro',
-    isa        => 'MongoDB::Database',
+    isa        => InstanceOf['MongoDB::Database'],
     lazy_build => 1,
 );
 
 sub _build__database {
     my ($self) = @_;
-    return $self->collection->_database;
+    return $self->collection->database;
 }
 
 has '_client' => (
     is         => 'ro',
-    isa        => 'MongoDB::MongoClient',
+    isa        => InstanceOf['MongoDB::MongoClient'],
     lazy_build => 1,
 );
 
@@ -143,7 +144,7 @@ sub find {
 #pod Queues a document for insertion when L</execute> is called.  The document may
 #pod be a hash reference, an array reference (with balance key/value pairs) or a
 #pod L<Tie::IxHash> object.  If the document does not have an C<_id> field, one will
-#pod be added.
+#pod be added to the original.
 #pod
 #pod The method has an empty return on success; an exception will be thrown on error.
 #pod
@@ -159,20 +160,10 @@ sub insert {
     if ( ref $doc eq 'ARRAY' ) {
         confess "array reference to insert must have key/value pairs"
           if @$doc % 2;
-        $doc = {@$doc};
-    }
-    elsif ( ref $doc eq 'HASH' ) {
-        $doc = {%$doc}; # shallow copy
-    }
-    else {
-        $doc = Tie::IxHash->new( map {; $_ => $doc->FETCH($_) } $doc->Keys );
-        $doc->STORE( '_id', MongoDB::OID->new ) unless $doc->EXISTS('_id');
-    }
-
-    if ( ref $doc eq 'HASH' ) {
-        $doc->{_id} = MongoDB::OID->new unless exists $doc->{_id};
+        $doc = Tie::IxHash->new(@$doc);
     }
 
+    $self->collection->_add_oids([$doc]);
     $self->_enqueue_write( [ insert => $doc ] );
     return;
 }
@@ -258,7 +249,7 @@ MongoDB::BulkWrite - MongoDB bulk write interface
 
 =head1 VERSION
 
-version v0.999.998.2
+version v0.999.998.3
 
 =head1 SYNOPSIS
 
@@ -351,7 +342,7 @@ An exception will be thrown on error.
 Queues a document for insertion when L</execute> is called.  The document may
 be a hash reference, an array reference (with balance key/value pairs) or a
 L<Tie::IxHash> object.  If the document does not have an C<_id> field, one will
-be added.
+be added to the original.
 
 The method has an empty return on success; an exception will be thrown on error.
 
