@@ -19,30 +19,57 @@ package MongoDB::BulkWriteResult;
 # ABSTRACT: MongoDB bulk write result document
 
 use version;
-our $VERSION = 'v0.999.998.2'; # TRIAL
+our $VERSION = 'v0.999.998.3'; # TRIAL
 
-# empty superclass for backcompatibility
+# empty superclass for backcompatibility; add a variable to the
+# package namespace so Perl thinks it's a real package
+$MongoDB::WriteResult::VERSION = $VERSION;
 our @ISA = qw/MongoDB::WriteResult/;
 
 use Moose;
 use MongoDB::Error;
-use MongoDB::_Types;
+use MongoDB::_Types -types;
+use Types::Standard -types;
 use Syntax::Keyword::Junction qw/any/;
 use namespace::clean -except => 'meta';
 
 with 'MongoDB::Role::_WriteResult';
 
-has upserted_ids => (
+has [qw/upserted inserted/] => (
     is      => 'ro',
-    isa     => 'ArrayOfHashRef',
+    isa     => ArrayOfHashRef,
     coerce  => 1,
     default => sub { [] },
 );
 
+has inserted_ids => (
+    is      => 'ro',
+    isa     => 'HashRef',
+    lazy    => 1,
+    builder => '_build_inserted_ids',
+);
+
+sub _build_inserted_ids {
+    my ($self) = @_;
+    return { map { $_->{index}, $_->{_id} } @{ $self->inserted } };
+}
+
+has upserted_ids => (
+    is      => 'ro',
+    isa     => 'HashRef',
+    lazy    => 1,
+    builder => '_build_upserted_ids',
+);
+
+sub _build_upserted_ids {
+    my ($self) = @_;
+    return { map { $_->{index}, $_->{_id} } @{ $self->upserted } };
+}
+
 for my $attr (qw/inserted_count upserted_count matched_count deleted_count/) {
     has $attr => (
         is      => 'ro',
-        isa     => 'Num',
+        isa     => Num,
         writer  => "_set_$attr",
         default => 0,
     );
@@ -55,21 +82,21 @@ for my $attr (qw/inserted_count upserted_count matched_count deleted_count/) {
 
 has modified_count => (
     is      => 'ro',
-    isa     => 'Maybe[Num]',
+    isa     => Maybe[Num],
     writer  => '_set_modified_count',
     default => undef,
 );
 
 has op_count => (
     is      => 'ro',
-    isa     => 'Num',
+    isa     => Num,
     writer  => '_set_op_count',
     default => 0,
 );
 
 has batch_count => (
     is      => 'ro',
-    isa     => 'Num',
+    isa     => Num,
     writer  => '_set_batch_count',
     default => 0,
 );
@@ -86,7 +113,6 @@ my %OLD_API_ALIASING = (
     nRemoved                 => 'deleted_count',
     writeErrors              => 'write_errors',
     writeConcernErrors       => 'write_concern_errors',
-    upserted                 => 'upserted_ids',
     count_writeErrors        => 'count_write_errors',
     count_writeConcernErrors => 'count_write_concern_errors',
 );
@@ -119,8 +145,8 @@ sub _parse_cmd_result {
         confess "parse requires 'op' and 'result' arguments";
     }
 
-    my ( $op, $op_count, $batch_count, $result ) =
-      @{$args}{qw/op op_count batch_count result/};
+    my ( $op, $op_count, $batch_count, $result, $cmd_doc ) =
+      @{$args}{qw/op op_count batch_count result cmd_doc/};
 
     $result = $result->result
       if eval { $result->isa("MongoDB::CommandResult") };
@@ -146,10 +172,22 @@ sub _parse_cmd_result {
     # if we have upserts, change type to calculate differently
     if ( $result->{upserted} ) {
         $op                      = 'upsert';
-        $attrs->{upserted_ids}   = $result->{upserted};
+        $attrs->{upserted}       = $result->{upserted};
         $attrs->{upserted_count} = @{ $result->{upserted} };
     }
 
+    # recover _ids from documents
+    if ( exists($result->{n}) && $op eq 'insert' ) {
+        my @pairs;
+        my $docs = {@$cmd_doc}->{documents};
+        for my $i ( 0 .. $result->{n}-1 ) {
+            my $doc = $docs->[$i];
+            my $id = ref($doc) eq 'HASH' ? $doc->{_id} : $doc->FETCH('_id');
+            push @pairs, { index => $i, _id => $id };
+        }
+        $attrs->{inserted} = \@pairs;
+    }
+
     # change 'n' into an op-specific count
     if ( exists $result->{n} ) {
         my ( $key, $builder ) = @{ $op_map{$op} };
@@ -183,7 +221,14 @@ sub _parse_write_op {
     # parse by type
     my $type = ref($op);
     if ( $type eq 'MongoDB::InsertOneResult' ) {
-        $attrs->{inserted_count} = $has_write_error ? 0 : 1;
+        if ( $has_write_error ) {
+            $attrs->{inserted_count} = 0;
+            $attrs->{inserted} = [];
+        }
+        else {
+            $attrs->{inserted_count} = 1;
+            $attrs->{inserted} = [ { index => 0, _id => $op->inserted_id } ];
+        }
     }
     elsif ( $type eq 'MongoDB::DeleteResult' ) {
         $attrs->{deleted_count} = $op->deleted_count;
@@ -191,7 +236,7 @@ sub _parse_write_op {
     elsif ( $type eq 'MongoDB::UpdateResult' ) {
         if ( defined $op->upserted_id ) {
             my $upsert = { index => 0, _id => $op->upserted_id };
-            $attrs->{upserted_ids}   = [$upsert];
+            $attrs->{upserted}       = [$upsert];
             $attrs->{upserted_count} = 1;
             # modified_count *must* always be defined for 2.6+ servers
             # matched_count is here for clarity and consistency
@@ -233,7 +278,7 @@ sub _merge_result {
 
     # Append error and upsert docs, but modify index based on op count
     my $op_count = $self->op_count;
-    for my $attr (qw/write_errors upserted_ids/) {
+    for my $attr (qw/write_errors upserted inserted/) {
         for my $doc ( @{ $result->$attr } ) {
             $doc->{index} += $op_count;
         }
@@ -265,7 +310,7 @@ MongoDB::BulkWriteResult - MongoDB bulk write result document
 
 =head1 VERSION
 
-version v0.999.998.2
+version v0.999.998.3
 
 =head1 SYNOPSIS
 
@@ -312,7 +357,7 @@ for a legacy server) this attribute will be C<undef>.
 
 =head2 upserted
 
-An array reference containing information about upserted documetns (if any).
+An array reference containing information about upserted documents (if any).
 Each document will have the following fields:
 
 =over 4
@@ -327,6 +372,21 @@ _id — the object ID of the upserted document
 
 =back
 
+=head2 upserted_ids
+
+A hash reference built lazily from C<upserted> mapping indexes to object
+IDs.
+
+=head2 inserted
+
+An array reference containing information about inserted documents (if any).
+Documents are just as in C<upserted>.
+
+=head2 inserted_ids
+
+A hash reference built lazily from C<inserted> mapping indexes to object
+IDs.
+
 =head2 write_errors
 
 An array reference containing write errors (if any).  Each error document
