@@ -19,18 +19,20 @@ package MongoDB::BulkWriteView;
 # ABSTRACT: Bulk write operations against a query document
 
 use version;
-our $VERSION = 'v0.999.998.2'; # TRIAL
+our $VERSION = 'v0.999.998.3'; # TRIAL
 
 use Moose;
 
 use Syntax::Keyword::Junction qw/any/;
+use MongoDB::_Types -types;
+use Types::Standard -types;
 use boolean;
 use namespace::clean -except => 'meta';
 
 # A hash reference containing a MongoDB query document
 has _query => (
     is       => 'ro',
-    isa      => 'IxHash',
+    isa      => IxHash,
     coerce   => 1,
     required => 1
 );
@@ -38,14 +40,14 @@ has _query => (
 # Originating bulk write object for executing write operations.
 has _bulk => (
     is       => 'ro',
-    isa      => 'MongoDB::BulkWrite',
+    isa      => InstanceOf['MongoDB::BulkWrite'],
     required => 1,
     handles  => [qw/_enqueue_write/]
 );
 
 has _upsert => (
     is      => 'ro',
-    isa     => 'boolean',
+    isa     => Booleanpm,
     default => sub { false },
 );
 
@@ -141,7 +143,7 @@ MongoDB::BulkWriteView - Bulk write operations against a query document
 
 =head1 VERSION
 
-version v0.999.998.2
+version v0.999.998.3
 
 =head1 SYNOPSIS
 
