@@ -20,7 +20,7 @@ package MongoDB::Code;
 # ABSTRACT: JavaScript Code
 
 use version;
-our $VERSION = 'v0.999.998.2'; # TRIAL
+our $VERSION = 'v0.999.998.3'; # TRIAL
 
 #pod =head1 NAME
 #pod
@@ -29,6 +29,7 @@ our $VERSION = 'v0.999.998.2'; # TRIAL
 #pod =cut
 
 use Moose;
+use Types::Standard -types;
 use namespace::clean -except => 'meta';
 
 #pod =head1 ATTRIBUTES
@@ -41,7 +42,7 @@ use namespace::clean -except => 'meta';
 
 has code => (
     is       => 'ro',
-    isa      => 'Str',
+    isa      => Str,
     required => 1,
 );
 
@@ -53,7 +54,7 @@ has code => (
 
 has scope => (
     is       => 'ro',
-    isa      => 'HashRef',
+    isa      => HashRef,
     required => 0,
 );
 
@@ -73,7 +74,7 @@ MongoDB::Code - JavaScript Code
 
 =head1 VERSION
 
-version v0.999.998.2
+version v0.999.998.3
 
 =head1 NAME
 
