@@ -19,10 +19,12 @@ package MongoDB::CommandResult;
 # ABSTRACT: MongoDB generic command result document
 
 use version;
-our $VERSION = 'v0.999.998.2'; # TRIAL
+our $VERSION = 'v0.999.998.3'; # TRIAL
 
 use Moose;
 use MongoDB::Error;
+use MongoDB::_Types -types;
+use Types::Standard -types;
 use namespace::clean -except => 'meta';
 
 with 'MongoDB::Role::_LastError';
@@ -35,7 +37,7 @@ with 'MongoDB::Role::_LastError';
 
 has result => (
     is       => 'ro',
-    isa      => 'HashRef',
+    isa      => HashRef,
     required => 1,
 );
 
@@ -47,7 +49,7 @@ has result => (
 
 has address => (
     is       => 'ro',
-    isa      => 'HostAddress',
+    isa      => HostAddress,
     required => 1,
 );
 
@@ -59,7 +61,16 @@ has address => (
 
 sub last_code {
     my ($self) = @_;
-    return $self->result->{code} || 0;
+    my $result = $self->result;
+    if ( $result->{code} ) {
+        return $result->{code};
+    }
+    elsif ( $result->{lastErrorObject} ) {
+        return $result->{lastErrorObject}{code} || 0;
+    }
+    else {
+        return 0;
+    }
 }
 
 #pod =method last_errmsg
@@ -118,7 +129,7 @@ MongoDB::CommandResult - MongoDB generic command result document
 
 =head1 VERSION
 
-version v0.999.998.2
+version v0.999.998.3
 
 =head1 DESCRIPTION
 
