@@ -20,7 +20,7 @@ package MongoDB::Cursor;
 # ABSTRACT: A lazy cursor for Mongo query results
 
 use version;
-our $VERSION = 'v0.999.998.2'; # TRIAL
+our $VERSION = 'v0.999.998.3'; # TRIAL
 
 use Moose;
 use MongoDB;
@@ -28,7 +28,8 @@ use MongoDB::BSON;
 use MongoDB::Error;
 use MongoDB::QueryResult;
 use MongoDB::_Protocol;
-use MongoDB::_Types;
+use MongoDB::_Types -types;
+use Types::Standard -types;
 use boolean;
 use Tie::IxHash;
 use Try::Tiny;
@@ -39,33 +40,9 @@ use constant {
     FLAG_ZERO => "\0" x 4,
 };
 
-#pod =head1 NAME
-#pod
-#pod MongoDB::Cursor - A cursor/iterator for Mongo query results
-#pod
-#pod =head1 SYNOPSIS
-#pod
-#pod     while (my $object = $cursor->next) {
-#pod         ...
-#pod     }
-#pod
-#pod     my @objects = $cursor->all;
-#pod
-#pod =head2 Multithreading
-#pod
-#pod Cursors are cloned in threads, but not reset.  Iterating the same cursor from
-#pod multiple threads will give unpredictable results.  Only iterate from a single
-#pod thread.
-#pod
-#pod =head1 SEE ALSO
-#pod
-#pod Core documentation on cursors: L<http://dochub.mongodb.org/core/cursors>.
-#pod
-#pod =cut
-
 $MongoDB::Cursor::_request_id = int(rand(1000000));
 
-#pod =head1 STATIC ATTRIBUTES
+#pod =head1 GLOBAL VARIABLES
 #pod
 #pod =head2 slave_okay
 #pod
@@ -92,9 +69,7 @@ $MongoDB::Cursor::slave_okay = 0;
 
 $MongoDB::Cursor::timeout = 30000;
 
-#pod =head1 ATTRIBUTES
-#pod
-#pod =head2 started_iterating
+#pod =attr started_iterating
 #pod
 #pod If this cursor has queried the database yet. Methods
 #pod modifying the query will complain if they are called
@@ -107,14 +82,14 @@ with 'MongoDB::Role::_Cursor';
 # attributes for sending a query
 has query => (
     is => 'ro',
-    isa => 'MongoDB::_Query',
+    isa => InstanceOf['MongoDB::_Query'],
     required => 1,
 );
 
 # lazy result attribute
 has result => (
     is        => 'ro',
-    isa       => 'MongoDB::QueryResult',
+    isa       => InstanceOf['MongoDB::QueryResult'],
     lazy      => 1,
     builder   => '_build_result',
     predicate => 'started_iterating',
@@ -201,7 +176,7 @@ sub fields {
     return $self;
 }
 
-#pod =head2 sort ($order)
+#pod =head2 sort
 #pod
 #pod     # sort by name, descending
 #pod     $cursor->sort([name => -1]);
@@ -523,7 +498,7 @@ sub explain {
     return $new_query->execute->next;
 }
 
-#pod =head2 count($all?)
+#pod =head2 count
 #pod
 #pod     my $num = $cursor->count;
 #pod     my $num = $cursor->skip(20)->count(1);
@@ -672,6 +647,8 @@ __PACKAGE__->meta->make_immutable;
 
 1;
 
+
+
 # vim: ts=4 sts=4 sw=4 et tw=75:
 
 __END__
@@ -686,7 +663,7 @@ MongoDB::Cursor - A lazy cursor for Mongo query results
 
 =head1 VERSION
 
-version v0.999.998.2
+version v0.999.998.3
 
 =head1 SYNOPSIS
 
@@ -696,21 +673,23 @@ version v0.999.998.2
 
     my @objects = $cursor->all;
 
+=head1 USAGE
+
 =head2 Multithreading
 
 Cursors are cloned in threads, but not reset.  Iterating the same cursor from
 multiple threads will give unpredictable results.  Only iterate from a single
 thread.
 
-=head1 NAME
+=head1 ATTRIBUTES
 
-MongoDB::Cursor - A cursor/iterator for Mongo query results
+=head2 started_iterating
 
-=head1 SEE ALSO
+If this cursor has queried the database yet. Methods
+modifying the query will complain if they are called
+after the database is queried.
 
-Core documentation on cursors: L<http://dochub.mongodb.org/core/cursors>.
-
-=head1 STATIC ATTRIBUTES
+=head1 GLOBAL VARIABLES
 
 =head2 slave_okay
 
@@ -729,14 +708,6 @@ usually a long time).
 This value is overridden by C<MongoDB::MongoClient::query_timeout> and never
 used.
 
-=head1 ATTRIBUTES
-
-=head2 started_iterating
-
-If this cursor has queried the database yet. Methods
-modifying the query will complain if they are called
-after the database is queried.
-
 =head1 QUERY MODIFIERS
 
 These methods modify the query to be run.  An exception will be thrown if
@@ -783,7 +754,7 @@ in the MongoDB documentation for details.
 
 Returns this cursor for chaining operations.
 
-=head2 sort ($order)
+=head2 sort
 
     # sort by name, descending
     $cursor->sort([name => -1]);
@@ -925,7 +896,7 @@ the time in milliseconds the query took to execute.
 See also core documentation on explain:
 L<http://dochub.mongodb.org/core/explain>.
 
-=head2 count($all?)
+=head2 count
 
     my $num = $cursor->count;
     my $num = $cursor->skip(20)->count(1);
@@ -1012,6 +983,10 @@ C<start> -- the index of the result that the current batch of results starts at.
 If the cursor has not yet executed, only the C<num> field will be returned with
 a value of 0.
 
+=head1 SEE ALSO
+
+Core documentation on cursors: L<http://dochub.mongodb.org/core/cursors>.
+
 =head1 AUTHORS
 
 =over 4
