@@ -20,13 +20,15 @@ package MongoDB::Database;
 # ABSTRACT: A MongoDB Database
 
 use version;
-our $VERSION = 'v0.999.998.2'; # TRIAL
+our $VERSION = 'v0.999.998.3'; # TRIAL
 
 use MongoDB::CommandResult;
 use MongoDB::Error;
 use MongoDB::GridFS;
 use MongoDB::Op::_ListCollections;
 use MongoDB::_Query;
+use MongoDB::_Types -types;
+use Types::Standard -types;
 use Carp 'carp';
 use boolean;
 use Moose;
@@ -35,7 +37,7 @@ use namespace::clean -except => 'meta';
 
 has _client => ( 
     is       => 'ro',
-    isa      => 'MongoDB::MongoClient',
+    isa      => InstanceOf['MongoDB::MongoClient'],
     required => 1,
 );
 
@@ -47,7 +49,7 @@ has _client => (
 
 has name => (
     is       => 'ro',
-    isa      => 'Str',
+    isa      => Str,
     required => 1,
 );
 
@@ -56,12 +58,13 @@ has name => (
 #pod A L<MongoDB::ReadPreference> object.  It may be initialized with a string
 #pod corresponding to one of the valid read preference modes or a hash reference
 #pod that will be coerced into a new MongoDB::ReadPreference object.
+#pod By default it will be inherited from a L<MongoDB::MongoClient> object.
 #pod
 #pod =cut
 
 has read_preference => (
     is       => 'ro',
-    isa      => 'ReadPreference',
+    isa      => ReadPreference,
     required => 1,
     coerce   => 1,
 );
@@ -70,12 +73,13 @@ has read_preference => (
 #pod
 #pod A L<MongoDB::WriteConcern> object.  It may be initialized with a hash
 #pod reference that will be coerced into a new MongoDB::WriteConcern object.
+#pod By default it will be inherited from a L<MongoDB::MongoClient> object.
 #pod
 #pod =cut
 
 has write_concern => (
     is       => 'ro',
-    isa      => 'WriteConcern',
+    isa      => WriteConcern,
     required => 1,
     coerce   => 1,
 );
@@ -129,30 +133,39 @@ sub get_collection {
         write_concern   => $self->write_concern,
         ( $options ? %$options : () ),
         # not allowed to be overridden by options
-        _database => $self,
-        name      => $collection_name,
+        database => $self,
+        name     => $collection_name,
     );
 }
 
 { no warnings 'once'; *coll = \&get_collection }
 
-#pod =method get_gridfs ($prefix?)
+#pod =method get_gridfs
 #pod
 #pod     my $grid = $database->get_gridfs;
+#pod     my $grid = $database->get_gridfs("fs");
+#pod     my $grid = $database->get_gridfs("fs", $options);
 #pod
 #pod Returns a L<MongoDB::GridFS> for storing and retrieving files from the database.
 #pod Default prefix is "fs", making C<$grid-E<gt>files> "fs.files" and C<$grid-E<gt>chunks>
 #pod "fs.chunks".
 #pod
+#pod It takes an optional hash reference of options that are passed to the
+#pod L<MongoDB::GridFS> constructor.
+#pod
 #pod See L<MongoDB::GridFS> for more information.
 #pod
 #pod =cut
 
 sub get_gridfs {
-    my ($self, $prefix) = @_;
+    my ($self, $prefix, $options) = @_;
     $prefix = "fs" unless $prefix;
 
     return MongoDB::GridFS->new(
+        read_preference => $self->read_preference,
+        write_concern   => $self->write_concern,
+        ( $options ? %$options : () ),
+        # not allowed to be overridden by options
         _database => $self,
         prefix => $prefix
     );
@@ -261,22 +274,9 @@ sub eval {
     }
 }
 
-#pod =method last_error (DEPRECATED)
-#pod
-#pod     my $err = $db->last_error({w => 2});
-#pod
-#pod Because write operations now return result information, this function is
-#pod deprecated.
-#pod
-#pod Finds out if the last database operation completed successfully. If a hash
-#pod reference of options is provided, they are included with the database command.
-#pod Throws an exception if C<getLastError> itself fails.
-#pod
-#pod See the
-#pod L<getLastError|http://docs.mongodb.org/manual/reference/command/getLastError/>
-#pod documentation for more on valid options and results.
-#pod
-#pod =cut
+#--------------------------------------------------------------------------#
+# deprecated methods
+#--------------------------------------------------------------------------#
 
 sub last_error {
     my ( $self, $opt ) = @_;
@@ -299,7 +299,7 @@ MongoDB::Database - A MongoDB Database
 
 =head1 VERSION
 
-version v0.999.998.2
+version v0.999.998.3
 
 =head1 SYNOPSIS
 
@@ -321,6 +321,33 @@ some convenience methods that use it.
 Generally, you never construct one of these directly with C<new>.  Instead, you
 call C<get_database> on a L<MongoDB::MongoClient> object.
 
+=head1 USAGE
+
+=head2 Error handling
+
+Unless otherwise explictly documented, all methods throw exceptions if
+an error occurs.  The error types are documented in L<MongoDB::Error>.
+
+To catch and handle errors, the L<Try::Tiny> and L<Safe::Isa> modules
+are recommended:
+
+    use Try::Tiny;
+    use Safe::Isa; # provides $_isa
+
+    try {
+        $db->run_command( @command )
+    }
+    catch {
+        if ( $_->$_isa("MongoDB::DuplicateKeyError" ) {
+            ...
+        }
+        else {
+            ...
+        }
+    };
+
+To retry failures automatically, consider using L<Try::Tiny::Retry>.
+
 =head1 ATTRIBUTES
 
 =head2 name
@@ -332,11 +359,13 @@ The name of the database.
 A L<MongoDB::ReadPreference> object.  It may be initialized with a string
 corresponding to one of the valid read preference modes or a hash reference
 that will be coerced into a new MongoDB::ReadPreference object.
+By default it will be inherited from a L<MongoDB::MongoClient> object.
 
 =head2 write_concern
 
 A L<MongoDB::WriteConcern> object.  It may be initialized with a hash
 reference that will be coerced into a new MongoDB::WriteConcern object.
+By default it will be inherited from a L<MongoDB::MongoClient> object.
 
 =head1 METHODS
 
@@ -360,14 +389,19 @@ L<MongoDB::Collection> constructor.
 
 The C<coll> method is an alias for C<get_collection>.
 
-=head2 get_gridfs ($prefix?)
+=head2 get_gridfs
 
     my $grid = $database->get_gridfs;
+    my $grid = $database->get_gridfs("fs");
+    my $grid = $database->get_gridfs("fs", $options);
 
 Returns a L<MongoDB::GridFS> for storing and retrieving files from the database.
 Default prefix is "fs", making C<$grid-E<gt>files> "fs.files" and C<$grid-E<gt>chunks>
 "fs.chunks".
 
+It takes an optional hash reference of options that are passed to the
+L<MongoDB::GridFS> constructor.
+
 See L<MongoDB::GridFS> for more information.
 
 =head2 drop
@@ -425,20 +459,20 @@ passed to the function.  C<$nolock> is a L<boolean> value.  For more examples of
 using eval see
 L<http://www.mongodb.org/display/DOCS/Server-side+Code+Execution#Server-sideCodeExecution-Using{{db.eval%28%29}}>.
 
-=head2 last_error (DEPRECATED)
+=for Pod::Coverage last_error
 
-    my $err = $db->last_error({w => 2});
+=head1 DEPRECATIONS
 
-Because write operations now return result information, this function is
-deprecated.
+The methods still exist, but are no longer documented.  In a future version
+they will warn when used, then will eventually be removed.
 
-Finds out if the last database operation completed successfully. If a hash
-reference of options is provided, they are included with the database command.
-Throws an exception if C<getLastError> itself fails.
+=over 4
 
-See the
-L<getLastError|http://docs.mongodb.org/manual/reference/command/getLastError/>
-documentation for more on valid options and results.
+=item *
+
+last_error
+
+=back
 
 =head1 AUTHORS
 
