@@ -19,10 +19,11 @@ package MongoDB::DeleteResult;
 # ABSTRACT: MongoDB deletion result object
 
 use version;
-our $VERSION = 'v0.999.998.2'; # TRIAL
+our $VERSION = 'v0.999.998.3'; # TRIAL
 
 use Moose;
-use MongoDB::_Types;
+use MongoDB::_Types -types;
+use Types::Standard -types;
 use namespace::clean -except => 'meta';
 
 with 'MongoDB::Role::_WriteResult';
@@ -42,7 +43,7 @@ with 'MongoDB::Role::_WriteResult';
 
 has deleted_count => (
     is      => 'ro',
-    isa     => 'Num',
+    isa     => Num,
     default => 0,
 );
 
@@ -82,7 +83,7 @@ MongoDB::DeleteResult - MongoDB deletion result object
 
 =head1 VERSION
 
-version v0.999.998.2
+version v0.999.998.3
 
 =head1 SYNOPSIS
 
