@@ -22,11 +22,12 @@ package MongoDB::Error;
 # ABSTRACT: MongoDB Driver Error classes
 
 use version;
-our $VERSION = 'v0.999.998.2'; # TRIAL
+our $VERSION = 'v0.999.998.3'; # TRIAL
 
 use Moose;
 use Moose::Meta::Class ();
-use MongoDB::_Types;
+use MongoDB::_Types -types;
+use Types::Standard -types;
 use Exporter 5.57 qw/import/;
 use namespace::clean -except => [ 'meta', 'import' ];
 
@@ -67,7 +68,7 @@ use overload (
 
 has message => (
     is      => 'ro',
-    isa     => 'ErrorStr',
+    isa     => ErrorStr,
     default => 'unspecified error',
 );
 
@@ -96,6 +97,7 @@ around BUILDARGS => sub {
 
 package MongoDB::DatabaseError;
 use Moose;
+use Types::Standard -types;
 use namespace::clean -except => 'meta';
 extends("MongoDB::Error");
 
@@ -110,7 +112,7 @@ has result => (
 
 has code => (
     is      => 'ro',
-    isa     => 'Num',
+    isa     => Num,
     builder => '_build_code',
 );
 
@@ -118,12 +120,14 @@ sub _build_code { return MongoDB::Error::UNKNOWN_ERROR() }
 
 package MongoDB::DocumentError;
 use Moose;
+use MongoDB::_Types -types;
+use Types::Standard -types;
 use namespace::clean -except => 'meta';
 extends("MongoDB::Error");
 
 has document => (
     is       => 'ro',
-    isa      => 'HashRef|IxHash',
+    isa      => HashRef|IxHash,
     required => 1,
 );
 
@@ -198,12 +202,13 @@ Moose::Meta::Class->create( __PACKAGE__, superclasses => ['MongoDB::Error'] );
 
 package MongoDB::_CommandSizeError;
 use Moose;
+use Types::Standard -types;
 use namespace::clean -except => 'meta';
 extends("MongoDB::Error");
 
 has size => (
     is       => 'ro',
-    isa      => 'Int',
+    isa      => Int,
     required => 1,
 );
 
@@ -219,7 +224,7 @@ MongoDB::Error - MongoDB Driver Error classes
 
 =head1 VERSION
 
-version v0.999.998.2
+version v0.999.998.3
 
 =head1 SYNOPSIS
 
@@ -319,6 +324,10 @@ Attributes include:
 
 result — response from a database command; this must impliement the C<last_errmsg> method
 
+=item *
+
+code — numeric error code; see L</ERROR CODES>; if no code was provided by the database, the C<UNKNOWN_ERROR> code will be substituted instead
+
 =back
 
 =head3 MongoDB::DuplicateKeyError
@@ -392,6 +401,28 @@ When server selection fails for a given operation, this is thrown. For example,
 attempting a write when no primary is available or reading with a specific mode
 and tag set and no servers match.
 
+=head1 ERROR CODES
+
+The following error code constants are automatically exported by this module:
+
+        BAD_VALUE                 => 2,
+        UNKNOWN_ERROR             => 8,
+        NAMESPACE_NOT_FOUND       => 26,
+        EXCEEDED_TIME_LIMIT       => 50,
+        COMMAND_NOT_FOUND         => 59,
+        WRITE_CONCERN_ERROR       => 64,
+        NOT_MASTER                => 10107,
+        DUPLICATE_KEY             => 11000,
+        DUPLICATE_KEY_UPDATE      => 11001, # legacy before 2.6
+        DUPLICATE_KEY_CAPPED      => 12582, # legacy before 2.6
+        UNRECOGNIZED_COMMAND      => 13390, # mongos error before 2.4
+        NOT_MASTER_NO_SLAVE_OK    => 13435,
+        NOT_MASTER_OR_SECONDARY   => 13436,
+        CANT_OPEN_DB_IN_READ_LOCK => 15927,
+
+This is a very, very small subset of error codes possible from the server,
+but covers some of the more common ones.
+
 =head1 AUTHORS
 
 =over 4
