@@ -20,39 +20,18 @@ package MongoDB::GridFS;
 # ABSTRACT: A file storage utility
 
 use version;
-our $VERSION = 'v0.999.998.2'; # TRIAL
+our $VERSION = 'v0.999.998.3'; # TRIAL
 
 use MongoDB::GridFS::File;
 use DateTime 0.78; # drops dependency on bug-prone Math::Round
 use Digest::MD5;
 use Moose;
+use MongoDB::WriteConcern;
+use MongoDB::_Types -types;
+use Types::Standard -types;
 use namespace::clean -except => 'meta';
 
-#pod =head1 NAME
-#pod
-#pod MongoDB::GridFS - A file storage utility
-#pod
-#pod =head1 SYNOPSIS
-#pod
-#pod     use MongoDB::GridFS;
-#pod
-#pod     my $grid = $database->get_gridfs;
-#pod     my $fh = IO::File->new("myfile", "r");
-#pod     $grid->insert($fh, {"filename" => "mydbfile"});
-#pod
-#pod There are two interfaces for GridFS: a file-system/collection-like interface
-#pod (insert, remove, drop, find_one) and a more general interface
-#pod (get, put, delete).  Their functionality is the almost identical (get, put and
-#pod delete are always safe ops, insert, remove, and find_one are optionally safe),
-#pod using one over the other is a matter of preference.
-#pod
-#pod =head1 SEE ALSO
-#pod
-#pod Core documentation on GridFS: L<http://dochub.mongodb.org/core/gridfs>.
-#pod
-#pod =head1 ATTRIBUTES
-#pod
-#pod =head2 chunk_size
+#pod =attr chunk_size
 #pod
 #pod The number of bytes per chunk.  Defaults to 261120 (255kb).
 #pod
@@ -62,11 +41,42 @@ $MongoDB::GridFS::chunk_size = 261120;
 
 has _database => (
     is       => 'ro',
-    isa      => 'MongoDB::Database',
+    isa      => InstanceOf['MongoDB::Database'],
     required => 1,
 );
 
-#pod =head2 prefix
+#pod =attr read_preference
+#pod
+#pod A L<MongoDB::ReadPreference> object.  It may be initialized with a string
+#pod corresponding to one of the valid read preference modes or a hash reference
+#pod that will be coerced into a new MongoDB::ReadPreference object.
+#pod By default it will be inherited from a L<MongoDB::Database> object.
+#pod
+#pod =cut
+
+has read_preference => (
+    is       => 'ro',
+    isa      => ReadPreference,
+    required => 1,
+    coerce   => 1,
+);
+
+#pod =attr write_concern
+#pod
+#pod A L<MongoDB::WriteConcern> object.  It may be initialized with a hash
+#pod reference that will be coerced into a new MongoDB::WriteConcern object.
+#pod By default it will be inherited from a L<MongoDB::Database> object.
+#pod
+#pod =cut
+
+has write_concern => (
+    is       => 'ro',
+    isa      => WriteConcern,
+    required => 1,
+    coerce   => 1,
+);
+
+#pod =attr prefix
 #pod
 #pod The prefix used for the collections.  Defaults to "fs".
 #pod
@@ -74,46 +84,43 @@ has _database => (
 
 has prefix => (
     is      => 'ro',
-    isa     => 'Str',
+    isa     => Str,
     default => 'fs'
 );
 
-#pod =head2 files
-#pod
-#pod Collection in which file metadata is stored.  Each document contains md5 and
-#pod length fields, plus user-defined metadata (and an _id).
-#pod
-#pod =cut
-
 has files => (
     is => 'ro',
-    isa => 'MongoDB::Collection',
+    isa => InstanceOf['MongoDB::Collection'],
     lazy_build => 1
 );
 
 sub _build_files {
     my $self = shift;
-    my $coll = $self->_database->get_collection($self->prefix . '.files');
+    my $coll = $self->_database->get_collection(
+        $self->prefix . '.files',
+        {
+            read_preference => $self->read_preference,
+            write_concern   => $self->write_concern
+        }
+    );
     return $coll;
 }
 
-#pod =head2 chunks
-#pod
-#pod Actual content of the files stored.  Each chunk contains up to 4Mb of data, as
-#pod well as a number (its order within the file) and a files_id (the _id of the file
-#pod in the files collection it belongs to).
-#pod
-#pod =cut
-
 has chunks => (
     is => 'ro',
-    isa => 'MongoDB::Collection',
+    isa => InstanceOf['MongoDB::Collection'],
     lazy_build => 1
 );
 
 sub _build_chunks {
     my $self = shift;
-    my $coll = $self->_database->get_collection($self->prefix . '.chunks');
+    my $coll = $self->_database->get_collection(
+        $self->prefix . '.chunks',
+        {
+            read_preference => $self->read_preference,
+            write_concern   => $self->write_concern
+        }
+    );
     return $coll;
 }
 
@@ -134,11 +141,9 @@ sub _ensure_indexes {
     $self->chunks->ensure_index(Tie::IxHash->new(files_id => 1, n => 1), {"safe" => 1, "unique" => 1});
 }
 
-#pod =head1 METHODS
+#pod =method get
 #pod
-#pod =head2 get($id)
-#pod
-#pod     my $file = $grid->get($id);
+#pod     $file = $grid->get($id);
 #pod
 #pod Get a file from GridFS based on its _id.  Returns a L<MongoDB::GridFS::File>.
 #pod
@@ -153,20 +158,15 @@ sub get {
     return $self->find_one({_id => $id});
 }
 
-#pod =head2 put($fh, $metadata)
+#pod =method put
 #pod
-#pod     my $id = $grid->put($fh, {filename => "pic.jpg"});
+#pod     $id = $grid->put($fh, $metadata);
+#pod     $id = $grid->put($fh, {filename => "pic.jpg"});
 #pod
 #pod Inserts a file into GridFS, adding a L<MongoDB::OID> as the _id field if the
 #pod field is not already defined.  This is a wrapper for C<MongoDB::GridFS::insert>,
 #pod see that method below for more information.
 #pod
-#pod To use a filename as the _id for subsequent C<get> calls, you must set _id
-#pod explicitly:
-#pod
-#pod     $grid->put($fh, {_id => "pic.jpg", filename => "pic.jpg"});
-#pod     my $file = $grid->get("pic.jpg");
-#pod
 #pod Returns the _id field.
 #pod
 #pod =cut
@@ -177,7 +177,7 @@ sub put {
     return $self->insert($fh, $metadata, {safe => 1});
 }
 
-#pod =head2 delete($id)
+#pod =method delete
 #pod
 #pod     $grid->delete($id)
 #pod
@@ -192,9 +192,10 @@ sub delete {
     $self->remove({_id => $id}, {safe => 1});
 }
 
-#pod =head2 find_one ($criteria?, $fields?)
+#pod =method find_one
 #pod
-#pod     my $file = $grid->find_one({"filename" => "foo.txt"});
+#pod     $file = $grid->find_one({"filename" => "foo.txt"});
+#pod     $file = $grid->find_one($criteria, $fields);
 #pod
 #pod Returns a matching MongoDB::GridFS::File or undef.
 #pod
@@ -202,74 +203,80 @@ sub delete {
 
 sub find_one {
     my ($self, $criteria, $fields) = @_;
+    $criteria ||= {};
 
     my $file = $self->files->find_one($criteria, $fields);
     return undef unless $file;
     return MongoDB::GridFS::File->new({_grid => $self,info => $file});
 }
 
-#pod =head2 remove ($criteria?, $options?)
+#pod =method remove
 #pod
 #pod     $grid->remove({"filename" => "foo.txt"});
+#pod     $grid->remove({"filename" => "foo.txt"}, $options);
 #pod
 #pod Cleanly removes files from the database.  C<$options> is a hash of options for
-#pod the remove.  Possible options are:
+#pod the remove.
 #pod
-#pod =over 4
+#pod A hashref of options may be provided with the following keys:
 #pod
-#pod =item just_one
-#pod If true, only one file matching the criteria will be removed.
-#pod
-#pod =item safe
-#pod If true, each remove will be checked for success and die on failure.
-#pod
-#pod =back
+#pod =for :list
+#pod * C<just_one>: If true, only one file matching the criteria will be removed.
+#pod * C<safe>: (DEPRECATED) If true, each remove will be checked for success and
+#pod   die on failure.  Set the L</write_concern> attribute instead.
 #pod
 #pod This method doesn't return anything.
 #pod
 #pod =cut
 
 sub remove {
-    my ($self, $criteria, $options) = @_;
+    my ( $self, $criteria, $options ) = @_;
+    $options ||= {};
 
-    my $just_one = 0;
-    my $safe = 0;
+    my $chunks =
+      exists $options->{safe}
+      ? $self->chunks->clone( write_concern => $self->_dynamic_write_concern($options) )
+      : $self->chunks;
 
-    if (defined $options) {
-        if (ref $options eq 'HASH') {
-            $just_one = $options->{just_one} && 1;
-            $safe = $options->{safe} && 1;
-        }
-        elsif ($options) {
-            $just_one = $options && 1;
-        }
-    }
+    my $files =
+      exists $options->{safe}
+      ? $self->files->clone( write_concern => $self->_dynamic_write_concern($options) )
+      : $self->files;
 
-    if ($just_one) {
-        my $meta = $self->files->find_one($criteria);
-        $self->chunks->remove({"files_id" => $meta->{'_id'}}, {safe => $safe});
-        $self->files->remove({"_id" => $meta->{'_id'}}, {safe => $safe});
+    if ( $options->{just_one} ) {
+        my $meta = $files->find_one($criteria);
+        $chunks->delete_many( { "files_id" => $meta->{'_id'} } );
+        $files->delete_one( { "_id" => $meta->{'_id'} } );
     }
     else {
-        my $cursor = $self->files->query($criteria);
-        while (my $meta = $cursor->next) {
-            $self->chunks->remove({"files_id" => $meta->{'_id'}}, {safe => $safe});
+        my $cursor = $files->find($criteria);
+        while ( my $meta = $cursor->next ) {
+            $chunks->delete_many( { "files_id" => $meta->{'_id'} } );
         }
-        $self->files->remove($criteria, {safe => $safe});
+        $files->delete_many($criteria);
     }
+    return;
 }
 
 
-#pod =head2 insert ($fh, $metadata?, $options?)
+#pod =method insert
 #pod
-#pod     my $id = $gridfs->insert($fh, {"content-type" => "text/html"});
+#pod     $id = $gridfs->insert($fh);
+#pod     $id = $gridfs->insert($fh, $metadata);
+#pod     $id = $gridfs->insert($fh, $metadata, $options);
+#pod
+#pod     $id = $gridfs->insert($fh, {"content-type" => "text/html"});
 #pod
 #pod Reads from a file handle into the database.  Saves the file with the given
-#pod metadata.  The file handle must be readable.  C<$options> can be
-#pod C<{"safe" => true}>, which will do safe inserts and check the MD5 hash
-#pod calculated by the database against an MD5 hash calculated by the local
-#pod filesystem.  If the two hashes do not match, then the chunks already inserted
-#pod will be removed and the program will die.
+#pod metadata.  The file handle must be readable.
+#pod
+#pod A hashref of options may be provided with the following keys:
+#pod
+#pod =for :list
+#pod * C<safe>: (DEPRECATED) Will do safe inserts and check the MD5 hash calculated
+#pod   by the database against an MD5 hash calculated by the local filesystem.  If
+#pod   the two hashes do not match, then the chunks already inserted will be removed
+#pod   and the program will die. Set the L</write_concern> attribute instead.
 #pod
 #pod Because C<MongoDB::GridFS::insert> takes a file handle, it can be used to insert
 #pod very long strings into the database (as well as files).  C<$fh> must be a
@@ -277,11 +284,10 @@ sub remove {
 #pod with:
 #pod
 #pod     # open the string like a file
-#pod     my $basic_fh;
 #pod     open($basic_fh, '<', \$very_long_string);
 #pod
 #pod     # turn the file handle into a FileHandle
-#pod     my $fh = FileHandle->new;
+#pod     $fh = FileHandle->new;
 #pod     $fh->fdopen($basic_fh, 'r');
 #pod
 #pod     $gridfs->insert($fh);
@@ -295,6 +301,16 @@ sub insert {
     confess "not a file handle" unless $fh;
     $metadata = {} unless $metadata && ref $metadata eq 'HASH';
 
+    my $chunks =
+      exists $options->{safe}
+      ? $self->chunks->clone( write_concern => $self->_dynamic_write_concern($options) )
+      : $self->chunks;
+
+    my $files =
+      exists $options->{safe}
+      ? $self->files->clone( write_concern => $self->_dynamic_write_concern($options) )
+      : $self->files;
+
     my $start_pos = $fh->getpos();
 
     my $id;
@@ -308,29 +324,31 @@ sub insert {
     my $n = 0;
     my $length = 0;
     while ((my $len = $fh->read(my $data, $MongoDB::GridFS::chunk_size)) != 0) {
-        $self->chunks->insert({"files_id" => $id,
+        $chunks->insert_one({"files_id" => $id,
                                "n"        => $n,
-                               "data"     => bless(\$data)}, $options);
+                               "data"     => bless(\$data)});
         $n++;
         $length += $len;
     }
+
     $fh->setpos($start_pos);
 
     my %copy = %{$metadata};
     # compare the md5 hashes
-    if ($options->{safe}) {
+    if ($files->write_concern->is_safe) {
         # get an md5 hash for the file. set the retry flag to 'true' incase the 
         # database, collection, or indexes are missing. That way we can recreate them 
         # retry the md5 calc.
-        my $result = $self->_calc_md5($id, $self->prefix, 1);
+        my $result = $self->_calc_md5($chunks, $id, $self->prefix, 1);
         $copy{"md5"} = $result->{"md5"};
 
         my $md5 = Digest::MD5->new;
         $md5->addfile($fh);
+        $fh->setpos($start_pos);
         my $digest = $md5->hexdigest;
         if ($digest ne $result->{md5}) {
             # cleanup and die
-            $self->chunks->remove({files_id => $id});
+            $chunks->delete_many({files_id => $id});
             die "md5 hashes don't match: database got $result->{md5}, fs got $digest";
         }
     }
@@ -339,16 +357,17 @@ sub insert {
     $copy{"chunkSize"} = $MongoDB::GridFS::chunk_size;
     $copy{"uploadDate"} = DateTime->now;
     $copy{"length"} = $length;
-    return $self->files->insert(\%copy, $options);
+    return $files->insert_one(\%copy)->inserted_id;
 }
 
 # Calculates the md5 of the file on the server
+# $chunks: collection object with correct write concern
 # $id    : reference to the object we want to hash
 # $root  : the namespace the file resides in
 # $retry : a flag which controls whether or not to retry the md5 calc. 
 #         (which is currently only if we are missing our indexes)
 sub _calc_md5 {
-    my ($self, $id, $root, $retry) = @_;
+    my ($self, $chunks, $id, $root, $retry) = @_;
    
     # Try to get an md5 hash for the file
     my $result = $self->_database->run_command(["filemd5", $id, "root" => $self->prefix]);
@@ -360,11 +379,11 @@ sub _calc_md5 {
         # but we wont pass set the $retry flag again. We don't want an infinite loop for any reason. 
         if ($retry == 1 && $result eq 'need an index on { files_id : 1 , n : 1 }'){
             $self->_ensure_indexes();
-            $result = $self->_calc_md5($id, $root, 0);
+            $result = $self->_calc_md5($chunks, $id, $root, 0);
         }
         # Well, something bad is happening, so lets clean up and die. 
         else{
-            $self->chunks->remove({files_id => $id});
+            $chunks->delete_many({files_id => $id});
             die "recieve an unexpected error from the server: $result";
         }
     }
@@ -373,9 +392,9 @@ sub _calc_md5 {
 }
 
 
-#pod =head2 drop
+#pod =method drop
 #pod
-#pod     @files = $grid->drop;
+#pod     $grid->drop;
 #pod
 #pod Removes all files' metadata and contents.
 #pod
@@ -393,7 +412,8 @@ sub drop {
 #pod
 #pod     @files = $grid->all;
 #pod
-#pod Returns a list of the files in the database.
+#pod Returns a list of the files in the database as L<MongoDB::GridFS::File>
+#pod objects.
 #pod
 #pod =cut
 
@@ -401,7 +421,7 @@ sub all {
     my ($self) = @_;
     my @ret;
 
-    my $cursor = $self->files->query;
+    my $cursor = $self->files->find({});
     while (my $meta = $cursor->next) {
         push @ret, MongoDB::GridFS::File->new(
             _grid => $self,
@@ -410,6 +430,26 @@ sub all {
     return @ret;
 }
 
+#--------------------------------------------------------------------------#
+# private methods
+#--------------------------------------------------------------------------#
+
+sub _dynamic_write_concern {
+    my ( $self, $opts ) = @_;
+
+    my $wc = $self->write_concern;
+
+    if ( !exists $opts->{safe} ) {
+        return $wc;
+    }
+    elsif ( $opts->{safe} ) {
+        return $wc->is_safe ? $wc : MongoDB::WriteConcern->new( w => 1 );
+    }
+    else {
+        return MongoDB::WriteConcern->new( w => 0 );
+    }
+}
+
 __PACKAGE__->meta->make_immutable;
 
 1;
@@ -426,29 +466,56 @@ MongoDB::GridFS - A file storage utility
 
 =head1 VERSION
 
-version v0.999.998.2
+version v0.999.998.3
 
 =head1 SYNOPSIS
 
-    use MongoDB::GridFS;
-
     my $grid = $database->get_gridfs;
     my $fh = IO::File->new("myfile", "r");
     $grid->insert($fh, {"filename" => "mydbfile"});
 
+=head1 DESCRIPTION
+
+This class models a GridFS file store in a MongoDB database and provides an API
+for interacting with it.
+
+Generally, you never construct one of these directly with C<new>.  Instead, you
+call C<get_gridfs> on a L<MongoDB::Database> object.
+
+=head1 USAGE
+
+=head2 API
+
 There are two interfaces for GridFS: a file-system/collection-like interface
 (insert, remove, drop, find_one) and a more general interface
 (get, put, delete).  Their functionality is the almost identical (get, put and
 delete are always safe ops, insert, remove, and find_one are optionally safe),
 using one over the other is a matter of preference.
 
-=head1 NAME
+=head2 Error handling
 
-MongoDB::GridFS - A file storage utility
+Unless otherwise explictly documented, all methods throw exceptions if
+an error occurs.  The error types are documented in L<MongoDB::Error>.
 
-=head1 SEE ALSO
+To catch and handle errors, the L<Try::Tiny> and L<Safe::Isa> modules
+are recommended:
 
-Core documentation on GridFS: L<http://dochub.mongodb.org/core/gridfs>.
+    use Try::Tiny;
+    use Safe::Isa; # provides $_isa
+
+    try {
+        $grid->get( $id )
+    }
+    catch {
+        if ( $_->$_isa("MongoDB::TimeoutError" ) {
+            ...
+        }
+        else {
+            ...
+        }
+    };
+
+To retry failures automatically, consider using L<Try::Tiny::Retry>.
 
 =head1 ATTRIBUTES
 
@@ -456,90 +523,103 @@ Core documentation on GridFS: L<http://dochub.mongodb.org/core/gridfs>.
 
 The number of bytes per chunk.  Defaults to 261120 (255kb).
 
+=head2 read_preference
+
+A L<MongoDB::ReadPreference> object.  It may be initialized with a string
+corresponding to one of the valid read preference modes or a hash reference
+that will be coerced into a new MongoDB::ReadPreference object.
+By default it will be inherited from a L<MongoDB::Database> object.
+
+=head2 write_concern
+
+A L<MongoDB::WriteConcern> object.  It may be initialized with a hash
+reference that will be coerced into a new MongoDB::WriteConcern object.
+By default it will be inherited from a L<MongoDB::Database> object.
+
 =head2 prefix
 
 The prefix used for the collections.  Defaults to "fs".
 
-=head2 files
-
-Collection in which file metadata is stored.  Each document contains md5 and
-length fields, plus user-defined metadata (and an _id).
-
-=head2 chunks
-
-Actual content of the files stored.  Each chunk contains up to 4Mb of data, as
-well as a number (its order within the file) and a files_id (the _id of the file
-in the files collection it belongs to).
-
 =head1 METHODS
 
-=head2 get($id)
+=head2 get
 
-    my $file = $grid->get($id);
+    $file = $grid->get($id);
 
 Get a file from GridFS based on its _id.  Returns a L<MongoDB::GridFS::File>.
 
 To retrieve a file based on metadata like C<filename>, use the L</find_one>
 method instead.
 
-=head2 put($fh, $metadata)
+=head2 put
 
-    my $id = $grid->put($fh, {filename => "pic.jpg"});
+    $id = $grid->put($fh, $metadata);
+    $id = $grid->put($fh, {filename => "pic.jpg"});
 
 Inserts a file into GridFS, adding a L<MongoDB::OID> as the _id field if the
 field is not already defined.  This is a wrapper for C<MongoDB::GridFS::insert>,
 see that method below for more information.
 
-To use a filename as the _id for subsequent C<get> calls, you must set _id
-explicitly:
-
-    $grid->put($fh, {_id => "pic.jpg", filename => "pic.jpg"});
-    my $file = $grid->get("pic.jpg");
-
 Returns the _id field.
 
-=head2 delete($id)
+=head2 delete
 
     $grid->delete($id)
 
 Removes the file with the given _id.  Will die if the remove is unsuccessful.
 Does not return anything on success.
 
-=head2 find_one ($criteria?, $fields?)
+=head2 find_one
 
-    my $file = $grid->find_one({"filename" => "foo.txt"});
+    $file = $grid->find_one({"filename" => "foo.txt"});
+    $file = $grid->find_one($criteria, $fields);
 
 Returns a matching MongoDB::GridFS::File or undef.
 
-=head2 remove ($criteria?, $options?)
+=head2 remove
 
     $grid->remove({"filename" => "foo.txt"});
+    $grid->remove({"filename" => "foo.txt"}, $options);
 
 Cleanly removes files from the database.  C<$options> is a hash of options for
-the remove.  Possible options are:
+the remove.
+
+A hashref of options may be provided with the following keys:
 
 =over 4
 
-=item just_one
-If true, only one file matching the criteria will be removed.
+=item *
 
-=item safe
-If true, each remove will be checked for success and die on failure.
+C<just_one>: If true, only one file matching the criteria will be removed.
+
+=item *
+
+C<safe>: (DEPRECATED) If true, each remove will be checked for success and die on failure.  Set the L</write_concern> attribute instead.
 
 =back
 
 This method doesn't return anything.
 
-=head2 insert ($fh, $metadata?, $options?)
+=head2 insert
 
-    my $id = $gridfs->insert($fh, {"content-type" => "text/html"});
+    $id = $gridfs->insert($fh);
+    $id = $gridfs->insert($fh, $metadata);
+    $id = $gridfs->insert($fh, $metadata, $options);
+
+    $id = $gridfs->insert($fh, {"content-type" => "text/html"});
 
 Reads from a file handle into the database.  Saves the file with the given
-metadata.  The file handle must be readable.  C<$options> can be
-C<{"safe" => true}>, which will do safe inserts and check the MD5 hash
-calculated by the database against an MD5 hash calculated by the local
-filesystem.  If the two hashes do not match, then the chunks already inserted
-will be removed and the program will die.
+metadata.  The file handle must be readable.
+
+A hashref of options may be provided with the following keys:
+
+=over 4
+
+=item *
+
+C<safe>: (DEPRECATED) Will do safe inserts and check the MD5 hash calculated by the database against an MD5 hash calculated by the local filesystem.  If the two hashes do not match, then the chunks already inserted will be removed and the program will die. Set the L</write_concern> attribute instead.
+
+=back
 
 Because C<MongoDB::GridFS::insert> takes a file handle, it can be used to insert
 very long strings into the database (as well as files).  C<$fh> must be a
@@ -547,18 +627,17 @@ FileHandle (not just the native file handle type), so you can insert a string
 with:
 
     # open the string like a file
-    my $basic_fh;
     open($basic_fh, '<', \$very_long_string);
 
     # turn the file handle into a FileHandle
-    my $fh = FileHandle->new;
+    $fh = FileHandle->new;
     $fh->fdopen($basic_fh, 'r');
 
     $gridfs->insert($fh);
 
 =head2 drop
 
-    @files = $grid->drop;
+    $grid->drop;
 
 Removes all files' metadata and contents.
 
@@ -566,11 +645,12 @@ Removes all files' metadata and contents.
 
     @files = $grid->all;
 
-Returns a list of the files in the database.
+Returns a list of the files in the database as L<MongoDB::GridFS::File>
+objects.
 
-=head1 AUTHOR
+=head1 SEE ALSO
 
-  Kristina Chodorow <kristina@mongodb.org>
+Core documentation on GridFS: L<http://dochub.mongodb.org/core/gridfs>.
 
 =head1 AUTHORS
 
