@@ -19,10 +19,11 @@ package MongoDB::InsertOneResult;
 # ABSTRACT: MongoDB single insert result object
 
 use version;
-our $VERSION = 'v0.999.998.2'; # TRIAL
+our $VERSION = 'v0.999.998.3'; # TRIAL
 
 use Moose;
-use MongoDB::_Types;
+use MongoDB::_Types -types;
+use Types::Standard -types;
 use namespace::clean -except => 'meta';
 
 with 'MongoDB::Role::_WriteResult';
@@ -42,7 +43,7 @@ with 'MongoDB::Role::_WriteResult';
 
 has inserted_id => (
     is  => 'ro',
-    isa => 'Any',
+    isa => Any,
 );
 
 __PACKAGE__->meta->make_immutable;
@@ -81,7 +82,7 @@ MongoDB::InsertOneResult - MongoDB single insert result object
 
 =head1 VERSION
 
-version v0.999.998.2
+version v0.999.998.3
 
 =head1 SYNOPSIS
 
