@@ -19,7 +19,7 @@ package MongoDB::MongoClient;
 # ABSTRACT: A connection to a MongoDB server or multi-server deployment
 
 use version;
-our $VERSION = 'v0.999.998.2'; # TRIAL
+our $VERSION = 'v0.999.998.3'; # TRIAL
 
 use Moose;
 use MongoDB;
@@ -43,7 +43,8 @@ use Syntax::Keyword::Junction 'any';
 use boolean;
 use Encode;
 use Try::Tiny;
-use MongoDB::_Types;
+use MongoDB::_Types -types;
+use Types::Standard -types;
 use namespace::clean -except => 'meta';
 
 use constant {
@@ -74,7 +75,7 @@ use constant {
 
 has host => (
     is      => 'ro',
-    isa     => 'Str',
+    isa     => Str,
     default => 'mongodb://localhost:27017', # XXX eventually, make this localhost
 );
 
@@ -87,7 +88,7 @@ has host => (
 
 has port => (
     is      => 'ro',
-    isa     => 'Int',
+    isa     => Int,
     default => 27017,
 );
 
@@ -110,7 +111,7 @@ has port => (
 
 has connect_type => (
     is      => 'ro',
-    isa     => 'ConnectType',
+    isa     => ConnectType,
     builder => '_build_connect_type',
     lazy    => 1
 );
@@ -123,7 +124,7 @@ has connect_type => (
 
 has timeout => (
     is      => 'rw',
-    isa     => 'Int',
+    isa     => Int,
     default => 20000,
 );
 
@@ -159,7 +160,7 @@ has timeout => (
 
 has query_timeout => (
     is      => 'rw',
-    isa     => 'Int',
+    isa     => Int,
     default => sub { return $MongoDB::Cursor::timeout; },
 );
 
@@ -201,7 +202,7 @@ has query_timeout => (
 
 has ssl => (
     is      => 'ro',
-    isa     => 'Bool|HashRef',
+    isa     => Bool|HashRef,
     default => 0,
     writer  => '_set_ssl',
 );
@@ -244,7 +245,7 @@ has ssl => (
 
 has w => (
     is      => 'rw',
-    isa     => 'Int|Str',
+    isa     => Int|Str,
     default => 1,
     trigger => \&_update_write_concern,
 );
@@ -262,7 +263,7 @@ has w => (
 
 has wtimeout => (
     is      => 'rw',
-    isa     => 'Int',
+    isa     => Int,
     default => 1000,
     trigger => \&_update_write_concern,
 );
@@ -278,7 +279,7 @@ has wtimeout => (
 
 has j => (
     is      => 'rw',
-    isa     => 'Bool',
+    isa     => Bool,
     default => 0,
     trigger => \&_update_write_concern,
 );
@@ -299,7 +300,7 @@ has j => (
 
 has server_selection_timeout_ms => (
     is      => 'ro',
-    isa     => 'Num',
+    isa     => Num,
     default => 30_000,
 );
 
@@ -322,7 +323,7 @@ has server_selection_timeout_ms => (
 
 has local_threshold_ms => (
     is      => 'ro',
-    isa     => 'Num',
+    isa     => Num,
     default => 15,
 );
 
@@ -343,7 +344,7 @@ has local_threshold_ms => (
 
 has read_preference => (
     is        => 'ro',
-    isa       => 'ReadPreference',
+    isa       => ReadPreference,
     writer    => '_set_read_preference',
     coerce    => 1,
     lazy      => 1,
@@ -366,7 +367,7 @@ sub _build__read_preference {
 
 has heartbeat_frequency_ms => (
     is      => 'ro',
-    isa     => 'Num',
+    isa     => Num,
     default => 60_000,
 );
 
@@ -383,7 +384,7 @@ has heartbeat_frequency_ms => (
 
 has username => (
     is      => 'rw',
-    isa     => 'Str',
+    isa     => Str,
     lazy    => 1,
     builder => '_build_username',
 );
@@ -397,7 +398,7 @@ has username => (
 
 has password => (
     is      => 'rw',
-    isa     => 'Str',
+    isa     => Str,
     lazy    => 1,
     builder => '_build_password',
 );
@@ -412,7 +413,7 @@ has password => (
 
 has db_name => (
     is      => 'rw',
-    isa     => 'Str',
+    isa     => Str,
     lazy    => 1,
     builder => '_build_db_name',
 );
@@ -439,7 +440,7 @@ has db_name => (
 
 has auth_mechanism => (
     is      => 'ro',
-    isa     => 'AuthMechanism',
+    isa     => AuthMechanism,
     lazy    => 1,
     builder => '_build_auth_mechanism',
     writer  => '_set_auth_mechanism',
@@ -454,7 +455,7 @@ has auth_mechanism => (
 
 has auth_mechanism_properties => (
     is      => 'ro',
-    isa     => 'HashRef',
+    isa     => HashRef,
     lazy    => 1,
     builder => '_build_auth_mechanism_properties',
     writer  => '_set_auth_mechanism_properties',
@@ -486,7 +487,7 @@ has dt_type => (
 
 has inflate_dbrefs => (
     is      => 'rw',
-    isa     => 'Bool',
+    isa     => Bool,
     default => 1
 );
 
@@ -498,7 +499,7 @@ has inflate_dbrefs => (
 
 has inflate_regexps => (
     is      => 'rw',
-    isa     => 'Bool',
+    isa     => Bool,
     default => 0,
 );
 
@@ -515,7 +516,7 @@ has inflate_regexps => (
 
 has auto_connect => (
     is      => 'ro',
-    isa     => 'Bool',
+    isa     => Bool,
     default => 1,
 );
 
@@ -528,7 +529,7 @@ has auto_connect => (
 
 has auto_reconnect => (
     is      => 'ro',
-    isa     => 'Bool',
+    isa     => Bool,
     default => 1,
 );
 
@@ -542,7 +543,7 @@ has auto_reconnect => (
 
 has find_master => (
     is      => 'ro',
-    isa     => 'Bool',
+    isa     => Bool,
     default => 0,
 );
 
@@ -555,7 +556,7 @@ has find_master => (
 
 has sasl => (
     is      => 'ro',
-    isa     => 'Bool',
+    isa     => Bool,
     default => 0
 );
 
@@ -568,7 +569,7 @@ has sasl => (
 
 has sasl_mechanism => (
     is      => 'ro',
-    isa     => 'AuthMechanism',
+    isa     => AuthMechanism,
     default => 'GSSAPI',
 );
 
@@ -578,7 +579,7 @@ has sasl_mechanism => (
 
 has _topology => (
     is         => 'ro',
-    isa        => 'MongoDB::_Topology',
+    isa        => InstanceOf['MongoDB::_Topology'],
     lazy_build => 1,
     handles    => { topology_type => 'type' },
     clearer    => '_clear__topology',
@@ -586,7 +587,7 @@ has _topology => (
 
 has _credential => (
     is         => 'ro',
-    isa        => 'MongoDB::_Credential',
+    isa        => InstanceOf['MongoDB::_Credential'],
     builder    => '_build__credential',
     lazy       => 1,
     writer     => '_set__credential',
@@ -594,26 +595,26 @@ has _credential => (
 
 has _min_wire_version => (
     is      => 'ro',
-    isa     => 'Int',
+    isa     => Int,
     default => 0
 );
 
 has _max_wire_version => (
     is      => 'ro',
-    isa     => 'Int',
+    isa     => Int,
     default => 3
 );
 
 has _uri => (
     is      => 'ro',
-    isa     => 'MongoDB::_URI',
+    isa     => InstanceOf['MongoDB::_URI'],
     lazy    => 1,
     builder => '_build__uri',
 );
 
 has _write_concern => (
     is     => 'ro',
-    isa    => 'MongoDB::WriteConcern',
+    isa    => InstanceOf['MongoDB::WriteConcern'],
     writer => '_set_write_concern',
 );
 
@@ -803,6 +804,13 @@ sub disconnect {
 # semantics might change in future releases
 #--------------------------------------------------------------------------#
 
+# Undocumented in old MongoDB::MongoClient; semantics don't translate, but
+# best approximation is checking if we can talk to a primary
+sub connected {
+    my ($self) = @_;
+    return try { !! $self->_topology->get_writable_link }
+}
+
 sub send_admin_command {
     my ( $self, $command, $read_preference ) = @_;
 
@@ -1074,7 +1082,7 @@ MongoDB::MongoClient - A connection to a MongoDB server or multi-server deployme
 
 =head1 VERSION
 
-version v0.999.998.2
+version v0.999.998.3
 
 =head1 SYNOPSIS
 
@@ -1520,6 +1528,12 @@ already did the proper hashing yourself.
 
 See also the L</AUTHENTICATION> section.
 
+=for Pod::Coverage connected
+send_admin_command
+send_direct_op
+send_read_op
+send_write_op
+
 =head1 DEPLOYMENT TOPOLOGY
 
 MongoDB can operate as a single server or as a distributed system.  One or more
