@@ -19,52 +19,20 @@ package MongoDB::OID;
 # ABSTRACT: A Mongo Object ID
 
 use version;
-our $VERSION = 'v0.999.998.2'; # TRIAL
+our $VERSION = 'v0.999.998.3'; # TRIAL
 
 use MongoDB::BSON;
 use Moose;
 use MongoDB;
+use Types::Standard -types;
 use namespace::clean -except => 'meta';
 
-#pod =head1 NAME
-#pod
-#pod MongoDB::OID - A Mongo ObjectId
-#pod
-#pod =head1 SYNOPSIS
-#pod
-#pod If no C<_id> field is provided when a document is inserted into the database, an 
-#pod C<_id> field will be added with a new C<MongoDB::OID> as its value.
-#pod
-#pod     my $id = $collection->insert({'name' => 'Alice', age => 20});
-#pod
-#pod C<$id> will be a C<MongoDB::OID> that can be used to retrieve or update the 
-#pod saved document:
-#pod
-#pod     $collection->update({_id => $id}, {'age' => {'$inc' => 1}});
-#pod     # now Alice is 21
-#pod
-#pod To create a copy of an existing OID, you must set the value attribute in the
-#pod constructor.  For example:
-#pod
-#pod     my $id1 = MongoDB::OID->new;
-#pod     my $id2 = MongoDB::OID->new(value => $id1->value);
-#pod     my $id3 = MongoDB::OID->new($id1->value);
-#pod     my $id4 = MongoDB::OID->new($id1);
-#pod
-#pod Now C<$id1>, C<$id2>, C<$id3> and C<$id4> will have the same value.
-#pod
-#pod OID generation is thread safe.
-#pod
-#pod =head1 SEE ALSO
-#pod
-#pod Core documentation on object ids: L<http://dochub.mongodb.org/core/objectids>.
-#pod
 #pod =head1 ATTRIBUTES
 #pod
 #pod =head2 value
 #pod
 #pod The OID value. A random value will be generated if none exists already.
-#pod It is a 24-character hexidecimal string (12 bytes).  
+#pod It is a 24-character hexidecimal string (12 bytes).
 #pod
 #pod Its string representation is the 24-character string.
 #pod
@@ -72,7 +40,7 @@ use namespace::clean -except => 'meta';
 
 has value => (
     is      => 'ro',
-    isa     => 'Str',
+    isa     => Str,
     required => 1,
     builder => '_build_value',
 );
@@ -117,7 +85,7 @@ sub to_string {
 #pod     my $date = DateTime->from_epoch(epoch => $id->get_time);
 #pod
 #pod Each OID contains a 4 bytes timestamp from when it was created.  This method
-#pod extracts the timestamp.  
+#pod extracts the timestamp.
 #pod
 #pod =cut
 
@@ -143,8 +111,8 @@ sub _get_pid {
 #pod     $json->encode(MongoDB::OID->new);
 #pod
 #pod Returns a JSON string for this OID.  This is compatible with the strict JSON
-#pod representation used by MongoDB, that is, an OID with the value 
-#pod "012345678901234567890123" will be represented as 
+#pod representation used by MongoDB, that is, an OID with the value
+#pod "012345678901234567890123" will be represented as
 #pod C<{"$oid" : "012345678901234567890123"}>.
 #pod
 #pod =cut
@@ -175,16 +143,16 @@ MongoDB::OID - A Mongo Object ID
 
 =head1 VERSION
 
-version v0.999.998.2
+version v0.999.998.3
 
 =head1 SYNOPSIS
 
-If no C<_id> field is provided when a document is inserted into the database, an 
+If no C<_id> field is provided when a document is inserted into the database, an
 C<_id> field will be added with a new C<MongoDB::OID> as its value.
 
     my $id = $collection->insert({'name' => 'Alice', age => 20});
 
-C<$id> will be a C<MongoDB::OID> that can be used to retrieve or update the 
+C<$id> will be a C<MongoDB::OID> that can be used to retrieve or update the
 saved document:
 
     $collection->update({_id => $id}, {'age' => {'$inc' => 1}});
@@ -202,20 +170,12 @@ Now C<$id1>, C<$id2>, C<$id3> and C<$id4> will have the same value.
 
 OID generation is thread safe.
 
-=head1 NAME
-
-MongoDB::OID - A Mongo ObjectId
-
-=head1 SEE ALSO
-
-Core documentation on object ids: L<http://dochub.mongodb.org/core/objectids>.
-
 =head1 ATTRIBUTES
 
 =head2 value
 
 The OID value. A random value will be generated if none exists already.
-It is a 24-character hexidecimal string (12 bytes).  
+It is a 24-character hexidecimal string (12 bytes).
 
 Its string representation is the 24-character string.
 
@@ -232,7 +192,7 @@ Gets the value of this OID as a 24-digit hexidecimal string.
     my $date = DateTime->from_epoch(epoch => $id->get_time);
 
 Each OID contains a 4 bytes timestamp from when it was created.  This method
-extracts the timestamp.  
+extracts the timestamp.
 
 =head2 TO_JSON
 
@@ -243,13 +203,13 @@ extracts the timestamp.
     $json->encode(MongoDB::OID->new);
 
 Returns a JSON string for this OID.  This is compatible with the strict JSON
-representation used by MongoDB, that is, an OID with the value 
-"012345678901234567890123" will be represented as 
+representation used by MongoDB, that is, an OID with the value
+"012345678901234567890123" will be represented as
 C<{"$oid" : "012345678901234567890123"}>.
 
-=head1 AUTHOR
+=head1 SEE ALSO
 
-  Kristina Chodorow <kristina@mongodb.org>
+Core documentation on object ids: L<http://dochub.mongodb.org/core/objectids>.
 
 =head1 AUTHORS
 
