@@ -20,7 +20,7 @@ package MongoDB::Op::_InsertOne;
 # MongoDB::InsertOneResult
 
 use version;
-our $VERSION = 'v0.999.998.2'; # TRIAL
+our $VERSION = 'v0.999.998.3'; # TRIAL
 
 use Moose;
 
@@ -28,20 +28,21 @@ use MongoDB::BSON;
 use MongoDB::Error;
 use MongoDB::InsertOneResult;
 use MongoDB::_Protocol;
-use MongoDB::_Types;
+use MongoDB::_Types -types;
+use Types::Standard -types;
 use Tie::IxHash;
 use boolean;
 use namespace::clean -except => 'meta';
 
 has db_name => (
     is       => 'ro',
-    isa      => 'Str',
+    isa      => Str,
     required => 1,
 );
 
 has coll_name => (
     is       => 'ro',
-    isa      => 'Str',
+    isa      => Str,
     required => 1,
 );
 
@@ -49,7 +50,7 @@ has coll_name => (
 # on legacy mongod does not use _id
 has document => (
     is       => 'ro',
-    isa      => 'IxHash',
+    isa      => IxHash,
     coerce   => 1,
     required => 1,
 );
@@ -97,7 +98,7 @@ sub _legacy_op_insert {
 
 sub _parse_cmd {
     my ( $self, $res ) = @_;
-    return inserted_id => $res->{ok} ? $self->document->FETCH("_id") : undef;
+    return ( $res->{ok} ? ( inserted_id => $self->document->FETCH("_id") ) : () );
 }
 
 BEGIN {
