@@ -20,32 +20,33 @@ package MongoDB::Op::_ListCollections;
 # names
 
 use version;
-our $VERSION = 'v0.999.998.2'; # TRIAL
+our $VERSION = 'v0.999.998.3'; # TRIAL
 
 use Moose;
 
 use MongoDB::Op::_Command;
 use MongoDB::Op::_Query;
 use MongoDB::QueryResult::Filtered;
-use MongoDB::_Types;
+use MongoDB::_Types -types;
+use Types::Standard -types;
 use Tie::IxHash;
 use namespace::clean -except => 'meta';
 
 has db_name => (
     is       => 'ro',
-    isa      => 'Str',
+    isa      => Str,
     required => 1,
 );
 
 has client => (
     is       => 'ro',
-    isa      => 'MongoDB::MongoClient',
+    isa      => InstanceOf['MongoDB::MongoClient'],
     required => 1,
 );
 
 has bson_codec => (
     is       => 'ro',
-    isa      => 'MongoDB::MongoClient', # XXX only for now
+    isa      => InstanceOf['MongoDB::MongoClient'], # XXX only for now
     required => 1,
 );
 
@@ -76,7 +77,7 @@ sub _command_list_colls {
 
     my $res = $op->execute( $link, $topology );
 
-    return $self->_build_query_result( $res );
+    return $self->_build_result_from_cursor( $res );
 }
 
 sub _legacy_list_colls {
