@@ -19,52 +19,53 @@ package MongoDB::Op::_Update;
 # Encapsulate an update operation; returns a MongoDB::UpdateResult
 
 use version;
-our $VERSION = 'v0.999.998.2'; # TRIAL
+our $VERSION = 'v0.999.998.3'; # TRIAL
 
 use Moose;
 
 use MongoDB::BSON;
 use MongoDB::UpdateResult;
 use MongoDB::_Protocol;
-use MongoDB::_Types;
+use MongoDB::_Types -types;
+use Types::Standard -types;
 use Tie::IxHash;
 use boolean;
 use namespace::clean -except => 'meta';
 
 has db_name => (
     is       => 'ro',
-    isa      => 'Str',
+    isa      => Str,
     required => 1,
 );
 
 has coll_name => (
     is       => 'ro',
-    isa      => 'Str',
+    isa      => Str,
     required => 1,
 );
 
 has filter => (
     is       => 'ro',
-    isa      => 'IxHash',
+    isa      => IxHash,
     coerce   => 1,
     required => 1,
 );
 
 has update => (
     is       => 'ro',
-    isa      => 'IxHash',
+    isa      => IxHash,
     coerce   => 1,
     required => 1,
 );
 
 has multi => (
     is     => 'ro',
-    isa    => 'Bool',
+    isa    => Bool,
 );
 
 has upsert => (
     is     => 'ro',
-    isa    => 'Bool',
+    isa    => Bool,
 );
 
 with qw/MongoDB::Role::_WriteOp/;
@@ -127,7 +128,7 @@ sub _parse_cmd {
     my ( $self, $res ) = @_;
 
     return (
-        matched_count  => $res->{n},
+        matched_count  => $res->{n} - @{ $res->{upserted} || [] },
         modified_count => $res->{nModified},
         upserted_id    => $res->{upserted} ? $res->{upserted}[0]{_id} : undef,
     );
@@ -154,7 +155,7 @@ sub _parse_gle {
     }
 
     return (
-        matched_count  => $res->{n},
+        matched_count  => ($upserted ? 0 : $res->{n}),
         modified_count => undef,
         upserted_id    => $upserted,
     );
