@@ -19,13 +19,14 @@ package MongoDB::QueryResult;
 # ABSTRACT: An iterator for Mongo query results
 
 use version;
-our $VERSION = 'v0.999.998.2'; # TRIAL
+our $VERSION = 'v0.999.998.3'; # TRIAL
 
 use Moose;
 use MongoDB::Error;
 use MongoDB::Op::_GetMore;
 use MongoDB::Op::_KillCursors;
-use MongoDB::_Types;
+use MongoDB::_Types -types;
+use Types::Standard -types;
 use namespace::clean -except => 'meta';
 
 use constant { CURSOR_ZERO => "\0" x 8, };
@@ -36,25 +37,25 @@ with 'MongoDB::Role::_Cursor';
 
 has _client => (
     is       => 'rw',
-    isa      => 'MongoDB::MongoClient',
+    isa      => InstanceOf['MongoDB::MongoClient'],
     required => 1,
 );
 
 has address => (
     is       => 'ro',
-    isa      => 'HostAddress',
+    isa      => HostAddress,
     required => 1,
 );
 
 has ns => (
     is       => 'ro',
-    isa      => 'Str',
+    isa      => Str,
     required => 1,
 );
 
 has batch_size => (
     is      => 'ro',
-    isa     => 'Int',
+    isa     => Int,
     default => 0,
 );
 
@@ -62,7 +63,7 @@ has batch_size => (
 
 has cursor_at => (
     is      => 'ro',
-    isa     => 'Num',
+    isa     => Num,
     traits  => ['Counter'],
     default => 0,
     handles => {
@@ -73,7 +74,7 @@ has cursor_at => (
 
 has limit => (
     is      => 'ro',
-    isa     => 'Num',
+    isa     => Num,
     default => 0,
 );
 
@@ -81,28 +82,28 @@ has limit => (
 
 has cursor_id => (
     is       => 'ro',
-    isa      => 'Str',
+    isa      => Str,
     required => 1,
     writer   => '_set_cursor_id',
 );
 
 has cursor_start => (
     is      => 'ro',
-    isa     => 'Num',
+    isa     => Num,
     default => 0,
     writer  => '_set_cursor_start',
 );
 
 has cursor_flags => (
     is      => 'ro',
-    isa     => 'HashRef',
+    isa     => HashRef,
     default => sub { {} },
     writer  => '_set_cursor_flags',
 );
 
 has cursor_num => (
     is      => 'ro',
-    isa     => 'Num',
+    isa     => Num,
     traits  => ['Counter'],
     default => 0,
     handles => {
@@ -113,7 +114,7 @@ has cursor_num => (
 
 has _docs => (
     is      => 'ro',
-    isa     => 'ArrayRef',
+    isa     => ArrayRef,
     traits  => ['Array'],
     default => sub { [] },
     handles => {
@@ -162,6 +163,7 @@ sub BUILDARGS {
 # for backward compatibility
 sub started_iterating() { 1 }
 
+# for backwards compatibility
 sub info {
     my ($self) = @_;
     return {
@@ -173,6 +175,18 @@ sub info {
     };
 }
 
+#pod =method has_next
+#pod
+#pod     if ( $response->has_next ) {
+#pod         ...
+#pod     }
+#pod
+#pod Returns true if additional documents are available.  This will
+#pod attempt to get another batch of documents from the server if
+#pod necessary.
+#pod
+#pod =cut
+
 sub has_next {
     my ($self) = @_;
     my $limit = $self->limit;
@@ -183,6 +197,16 @@ sub has_next {
     return !$self->_drained || $self->_get_more;
 }
 
+#pod =method next
+#pod
+#pod     while ( $doc = $result->next ) {
+#pod         process_doc($doc)
+#pod     }
+#pod
+#pod Returns the next document or C<undef> if the server cursor is exhausted.
+#pod
+#pod =cut
+
 sub next {
     my ($self) = @_;
     return unless $self->has_next;
@@ -215,6 +239,14 @@ sub _get_more {
     return scalar @{ $result->{docs} };
 }
 
+#pod =method all
+#pod
+#pod     @docs = $result->all;
+#pod
+#pod Returns all documents as a list.
+#pod
+#pod =cut
+
 sub all {
     my ($self) = @_;
     my @ret;
@@ -267,6 +299,49 @@ sub _pack_cursor_id {
 
 __PACKAGE__->meta->make_immutable;
 
+#pod =for Pod::Coverage
+#pod started_iterating
+#pod info
+#pod
+#pod =head1 SYNOPSIS
+#pod
+#pod     $cursor = $coll->find( $filter );
+#pod     $resuilt = $cursor->result;
+#pod
+#pod     while ( $doc = $result->next ) {
+#pod         process_doc($doc)
+#pod     }
+#pod
+#pod =head1 DESCRIPTION
+#pod
+#pod This class defines an iterator against a query result.  It automatically
+#pod fetches additional results from the originating mongod/mongos server
+#pod on demand.
+#pod
+#pod For backwards compatibility reasons, L<MongoDB::Cursor> encapsulates query
+#pod parameters and generates a C<MongoDB::QueryResult> object on demand.  All
+#pod iterators on C<MongoDB::Cursor> delegate to C<MongoDB::QueryResult> object.
+#pod
+#pod Retrieving this object and iterating on it directly will be slightly
+#pod more efficient.
+#pod
+#pod =head1 USAGE
+#pod
+#pod =head2 Error handling
+#pod
+#pod Unless otherwise explictly documented, all methods throw exceptions if
+#pod an error occurs.  The error types are documented in L<MongoDB::Error>.
+#pod
+#pod To catch and handle errors, the L<Try::Tiny> and L<Safe::Isa> modules
+#pod are recommended:
+#pod
+#pod =head2 Cursor destruction
+#pod
+#pod When a C<MongoDB::QueryResult> object is destroyed, a cursor termination
+#pod request will be sent to the originating server to free server resources.
+#pod
+#pod =cut
+
 1;
 
 __END__
@@ -281,7 +356,73 @@ MongoDB::QueryResult - An iterator for Mongo query results
 
 =head1 VERSION
 
-version v0.999.998.2
+version v0.999.998.3
+
+=head1 SYNOPSIS
+
+    $cursor = $coll->find( $filter );
+    $resuilt = $cursor->result;
+
+    while ( $doc = $result->next ) {
+        process_doc($doc)
+    }
+
+=head1 DESCRIPTION
+
+This class defines an iterator against a query result.  It automatically
+fetches additional results from the originating mongod/mongos server
+on demand.
+
+For backwards compatibility reasons, L<MongoDB::Cursor> encapsulates query
+parameters and generates a C<MongoDB::QueryResult> object on demand.  All
+iterators on C<MongoDB::Cursor> delegate to C<MongoDB::QueryResult> object.
+
+Retrieving this object and iterating on it directly will be slightly
+more efficient.
+
+=head1 USAGE
+
+=head2 Error handling
+
+Unless otherwise explictly documented, all methods throw exceptions if
+an error occurs.  The error types are documented in L<MongoDB::Error>.
+
+To catch and handle errors, the L<Try::Tiny> and L<Safe::Isa> modules
+are recommended:
+
+=head2 Cursor destruction
+
+When a C<MongoDB::QueryResult> object is destroyed, a cursor termination
+request will be sent to the originating server to free server resources.
+
+=head1 METHODS
+
+=head2 has_next
+
+    if ( $response->has_next ) {
+        ...
+    }
+
+Returns true if additional documents are available.  This will
+attempt to get another batch of documents from the server if
+necessary.
+
+=head2 next
+
+    while ( $doc = $result->next ) {
+        process_doc($doc)
+    }
+
+Returns the next document or C<undef> if the server cursor is exhausted.
+
+=head2 all
+
+    @docs = $result->all;
+
+Returns all documents as a list.
+
+=for Pod::Coverage started_iterating
+info
 
 =head1 AUTHORS
 
