@@ -19,9 +19,10 @@ package MongoDB::QueryResult::Filtered;
 # ABSTRACT: An iterator for Mongo query results with client-side filtering
 
 use version;
-our $VERSION = 'v0.999.998.2'; # TRIAL
+our $VERSION = 'v0.999.998.3'; # TRIAL
 
 use Moose;
+use Types::Standard -types;
 
 extends 'MongoDB::QueryResult';
 
@@ -29,7 +30,7 @@ use namespace::clean -except => 'meta';
 
 has post_filter => (
     is       => 'ro',
-    isa      => 'CodeRef',
+    isa      => CodeRef,
     required => 1,
 );
 
@@ -72,7 +73,9 @@ MongoDB::QueryResult::Filtered - An iterator for Mongo query results with client
 
 =head1 VERSION
 
-version v0.999.998.2
+version v0.999.998.3
+
+=for Pod::Coverage has_next
 
 =head1 AUTHORS
 
