@@ -19,10 +19,11 @@ package MongoDB::ReadPreference;
 # ABSTRACT: Encapsulate and validate read preferences
 
 use version;
-our $VERSION = 'v0.999.998.2'; # TRIAL
+our $VERSION = 'v0.999.998.3'; # TRIAL
 
 use Moose;
-use MongoDB::_Types;
+use MongoDB::_Types -types;
+use Types::Standard -types;
 use namespace::clean -except => 'meta';
 
 use overload (
@@ -46,7 +47,7 @@ use overload (
 
 has mode => (
     is      => 'ro',
-    isa     => 'ReadPrefMode',
+    isa     => ReadPrefMode,
     default => 'primary',
     coerce  => 1,
 );
@@ -63,7 +64,7 @@ has mode => (
 
 has tag_sets => (
     is      => 'ro',
-    isa     => 'ArrayOfHashRef',
+    isa     => ArrayOfHashRef,
     default => sub { [ {} ] },
     coerce  => 1,
 );
@@ -126,7 +127,7 @@ MongoDB::ReadPreference - Encapsulate and validate read preferences
 
 =head1 VERSION
 
-version v0.999.998.2
+version v0.999.998.3
 
 =head1 SYNOPSIS
 
