@@ -19,22 +19,17 @@ package MongoDB::Role::_CommandCursorOp;
 # MongoDB interface for database commands with cursors
 
 use version;
-our $VERSION = 'v0.999.998.2'; # TRIAL
+our $VERSION = 'v0.999.998.3'; # TRIAL
 
 use MongoDB::Error;
 use MongoDB::QueryResult;
 use Moose::Role;
+use Types::Standard -types;
 use namespace::clean -except => 'meta';
 
 requires 'client';
 
-has 'cursor_options' => (
-    is      => 'ro',
-    isa     => 'HashRef',
-    default => sub { {} },
-);
-
-sub _build_query_result {
+sub _build_result_from_cursor {
     my ( $self, $res ) = @_;
 
     my $cursor = $res->result->{cursor}
