@@ -19,11 +19,13 @@ package MongoDB::Role::_ReadOp;
 # MongoDB role for read ops that provides read preference
 
 use version;
-our $VERSION = 'v0.999.998.2'; # TRIAL
+our $VERSION = 'v0.999.998.3'; # TRIAL
 
 use Moose::Role;
 
-use MongoDB::_Types;
+use MongoDB::ReadPreference;
+use MongoDB::_Types -types;
+use Types::Standard -types;
 use namespace::clean -except => 'meta';
 
 my $PRIMARY = MongoDB::ReadPreference->new;
@@ -32,7 +34,7 @@ with 'MongoDB::Role::_DatabaseOp';
 
 has read_preference => (
     is      => 'ro',
-    isa     => 'ReadPreference',
+    isa     => ReadPreference,
     coerce  => 1,
     default => sub { $PRIMARY },
 );
