@@ -19,13 +19,14 @@ package MongoDB::Role::_WriteOp;
 # MongoDB interface for database write operations
 
 use version;
-our $VERSION = 'v0.999.998.2'; # TRIAL
+our $VERSION = 'v0.999.998.3'; # TRIAL
 
 use MongoDB::BSON;
 use MongoDB::CommandResult;
 use MongoDB::Error;
 use MongoDB::_Protocol;
-use MongoDB::_Types;
+use MongoDB::_Types -types;
+use Types::Standard -types;
 use Moose::Role;
 use Syntax::Keyword::Junction qw/any/;
 use namespace::clean -except => 'meta';
@@ -41,7 +42,7 @@ requires qw/db_name _parse_cmd _parse_gle/;
 
 has write_concern => (
     is       => 'ro',
-    isa      => 'WriteConcern',
+    isa      => WriteConcern,
     required => 1,
 );
 
