@@ -19,22 +19,23 @@ package MongoDB::Role::_WriteResult;
 # MongoDB interface for common write result attributes and methods
 
 use version;
-our $VERSION = 'v0.999.998.2'; # TRIAL
+our $VERSION = 'v0.999.998.3'; # TRIAL
 
 use MongoDB::Error;
-use MongoDB::_Types;
+use MongoDB::_Types -types;
+use Types::Standard -types;
 use Moose::Role;
 use namespace::clean -except => 'meta';
 
 has acknowledged => (
     is      => 'ro',
-    isa     => 'Bool',
+    isa     => Bool,
     default => 1,
 );
 
 has [qw/write_errors write_concern_errors/] => (
     is      => 'ro',
-    isa     => 'ArrayOfHashRef',
+    isa     => ArrayOfHashRef,
     coerce  => 1,
     default => sub { [] },
 );
