@@ -15,32 +15,16 @@
 #
 
 package MongoDB::Timestamp;
-
-
 # ABSTRACT: Replication timestamp
 
 use version;
-our $VERSION = 'v0.999.998.2'; # TRIAL
-
-#pod =head1 NAME
-#pod
-#pod MongoDB::Timestamp - Timestamp used for replication
-#pod
-#pod =head1 SYNOPSIS
-#pod
-#pod This is an internal type used for replication.  It is not for storing dates,
-#pod times, or timestamps in the traditional sense.  Unless you are looking to mess
-#pod with MongoDB's replication internals, the class you are probably looking for is
-#pod L<DateTime>.  See <MongoDB::DataTypes> for more information.
-#pod
-#pod =cut
+our $VERSION = 'v0.999.998.3'; # TRIAL
 
 use Moose;
+use Types::Standard -types;
 use namespace::clean -except => 'meta';
 
-#pod =head1 ATTRIBUTES
-#pod
-#pod =head2 sec
+#pod =attr sec
 #pod
 #pod Seconds since epoch.
 #pod
@@ -48,11 +32,11 @@ use namespace::clean -except => 'meta';
 
 has sec => (
     is       => 'ro',
-    isa      => 'Int',
+    isa      => Int,
     required => 1,
 );
 
-#pod =head2 inc
+#pod =attr inc
 #pod
 #pod Incrementing field.
 #pod
@@ -60,7 +44,7 @@ has sec => (
 
 has inc => (
     is       => 'ro',
-    isa      => 'Int',
+    isa      => Int,
     required => 1,
 );
 
@@ -80,18 +64,14 @@ MongoDB::Timestamp - Replication timestamp
 
 =head1 VERSION
 
-version v0.999.998.2
+version v0.999.998.3
 
-=head1 SYNOPSIS
+=head1 DESCRIPTION
 
 This is an internal type used for replication.  It is not for storing dates,
 times, or timestamps in the traditional sense.  Unless you are looking to mess
 with MongoDB's replication internals, the class you are probably looking for is
-L<DateTime>.  See <MongoDB::DataTypes> for more information.
-
-=head1 NAME
-
-MongoDB::Timestamp - Timestamp used for replication
+L<DateTime>.  See L<MongoDB::DataTypes> for more information.
 
 =head1 ATTRIBUTES
 
