@@ -19,46 +19,72 @@ package MongoDB::WriteConcern;
 # ABSTRACT: Encapsulate and validate a write concern
 
 use version;
-our $VERSION = 'v0.999.998.2'; # TRIAL
+our $VERSION = 'v0.999.998.3'; # TRIAL
 
 use Moose;
 use MongoDB::Error;
-use MongoDB::_Types;
+use MongoDB::_Types -types;
+use Types::Standard -types;
 use Scalar::Util qw/looks_like_number/;
 use namespace::clean -except => 'meta';
 
+#pod =attr w
+#pod
+#pod Specifies the desired acknowledgement level. Defaults to '1'.
+#pod
+#pod =cut
+
 has w => (
     is        => 'ro',
-    isa       => 'Str',
+    isa       => Str,
     predicate => '_has_w',
     default   => 1,
 );
 
+#pod =attr wtimeout
+#pod
+#pod Specifies how long to wait for the write concern to be satisfied (in
+#pod milliseonds).  Defaults to 1000.
+#pod
+#pod =cut
+
 has wtimeout => (
     is        => 'ro',
-    isa       => 'Num',
+    isa       => Num,
     predicate => '_has_wtimeout',
     default   => 1000,
 );
 
+#pod =attr j
+#pod
+#pod The j option confirms that the mongod instance has written the data to the
+#pod on-disk journal.  Defaults to false.
+#pod
+#pod B<Note>: specifying a write concern that set j to a true value may result in an
+#pod error with a mongod or mongos running with --nojournal option now errors.
+#pod
+#pod =cut
+
 has j => (
     is        => 'ro',
-    isa       => 'booleanpm',
+    isa       => Booleanpm,
     coerce    => 1,
     predicate => '_has_j',
 );
 
-has is_safe => (
+has _is_safe => (
     is      => 'ro',
-    isa     => 'Bool',
+    isa     => Bool,
     lazy    => 1,
+    reader  => 'is_safe',
     builder => '_build_is_safe',
 );
 
-has as_struct => (
+has _as_struct => (
     is      => 'ro',
-    isa     => 'HashRef',
+    isa     => HashRef,
     lazy    => 1,
+    reader  => 'as_struct',
     builder => '_build_as_struct',
 );
 
@@ -104,7 +130,43 @@ MongoDB::WriteConcern - Encapsulate and validate a write concern
 
 =head1 VERSION
 
-version v0.999.998.2
+version v0.999.998.3
+
+=head1 SYNOPSIS
+
+    $rp = MongoDB::WriteConcern->new(); # w:1, wtimeout: 1000
+
+    $rp = MongoDB::WriteConcern->new(
+        w        => 'majority',
+        wtimeout => 10000, # milliseconds
+    );
+
+=head1 DESCRIPTION
+
+A write concern describes the guarantee that MongoDB provides when reporting on
+the success of a write operation.
+
+For core documentation on read preference see
+L<http://docs.mongodb.org/manual/core/read-preference/>.
+
+=head1 ATTRIBUTES
+
+=head2 w
+
+Specifies the desired acknowledgement level. Defaults to '1'.
+
+=head2 wtimeout
+
+Specifies how long to wait for the write concern to be satisfied (in
+milliseonds).  Defaults to 1000.
+
+=head2 j
+
+The j option confirms that the mongod instance has written the data to the
+on-disk journal.  Defaults to false.
+
+B<Note>: specifying a write concern that set j to a true value may result in an
+error with a mongod or mongos running with --nojournal option now errors.
 
 =head1 AUTHORS
 
